<?php if ( ! defined( 'ABSPATH' ) ) {
	die;
} // Cannot access directly.

/**
 * The Layout building class.
 */
class PDT_Display {


	/**
	 * Display options section metabox.
	 *
	 * @param string $prefix The metabox key.
	 * @return void
	 */
	public static function section( $prefix ) {
		PDT::createSection(
			$prefix,
			array(
				'title'  => esc_html__( 'DISPLAY OPTIONS', 'productify-pro' ),
				'icon'   => 'fas fa-th-large',
				'fields' => array(
					array(
						'id'         => 'section_title',
						'type'       => 'switcher',
						'title'      => esc_html__( 'Section Title ', 'productify-pro' ),
						'subtitle'   => esc_html__( 'Show/Hide item showcase section title.', 'productify-pro' ),
						'default'    => false,
						'text_on'    => esc_html__( 'Show', 'productify-pro' ),
						'text_off'   => esc_html__( 'Hide', 'productify-pro' ),
						'text_width' => 75,
					),
					array(
						'id'              => 'section_title_margin',
						'type'            => 'spacing',
						'title'           => esc_html__( 'Section Title Margin', 'productify-pro' ),
						'subtitle'        => esc_html__( 'Set margin for the section title.', 'productify-pro' ),
						'all_icon'        => '<i class="fas fa-long-arrow-down"></i>',
						'units'           => array(
							'px',
						),
						'all_placeholder' => 'margin',
						'default'         => array(
							'top'    => '0',
							'right'  => '0',
							'bottom' => '30',
							'top'    => '0',
						),
						'dependency'      => array(
							'section_title',
							'==',
							'true',
							true,
						),
					),
					array(
						'id'         => 'pdt_number_of_columns',
						'type'       => 'column',
						'title'      => esc_html__( 'Column(s)', 'productify-pro' ),
						'subtitle'   => esc_html__( 'Set number of column(s) in different devices for responsive view.', 'productify-pro' ),
						'default'    => array(
							'lg_desktop'       => '3',
							'desktop'          => '3',
							'tablet'           => '2',
							'mobile_landscape' => '2',
							'mobile'           => '1',
						),
						'min'        => '1',
						'dependency' => array( 'pdt_layout_preset', 'any', 'carousel_layout,grid_layout,filter_layout,large_with_small', true ),
						'help'       => wp_kses(
							esc_html__( '<i class="fa fa-television"></i> <b> Large Desktop </b> - is larger than 1200px,<br><i class="fa fa-desktop"></i> <b>Desktop</b> - size is larger than 992px,<br> <i class="fa fa-tablet"></i> <b>Tablet</b> - Size is larger than 768,<br> <i class="fa fa-mobile"></i> <b> Mobile Landscape </b> - size is larger than 576px.,<br> <i class="fa fa-mobile"></i> <b> Mobile </b> - size is smaller than 576px.', 'productify-pro' ),
							array(
								'i'  => array( 'class' => array() ),
								'br' => array(),
							)
						),
					),
					array(
						'id'              => 'margin_between_post',
						'type'            => 'spacing',
						'title'           => esc_html__( 'Margin Between Columns', 'productify-pro' ),
						'subtitle'        => esc_html__( 'Set margin between columns (items).', 'productify-pro' ),
						'all'             => true,
						'all_icon'        => '<i class="fas fa-arrows-h"></i>',
						'units'           => array(
							'px',
						),
						'all_placeholder' => 'margin',
						'default'         => array(
							'all' => '20',
						),
					),
					array(
						'id'         => 'post_content_orientation',
						'type'       => 'layout_preset',
						'title'      => esc_html__( 'Content Orientation ', 'productify-pro' ),
						'subtitle'   => esc_html__( 'Set a position for the item content.', 'productify-pro' ),
						'desc'       => esc_html__( 'More amazing Content Orientation and Layout', 'productify-pro' ),
						'class'      => 'pdt-content-orientation',
						'options'    => array(
							'default' => array(
								'image' => PDT_URL . 'admin/views/ta-framework/assets/img/default.png',
								'text'  => esc_html__( 'Default', 'productify-pro' ),
							),
							'overlay' => array(
								'image'    => PDT_URL . 'admin/views/ta-framework/assets/img/overlay.png',
								'text'     => esc_html__( 'Overlay', 'productify-pro' ),
								'pro_only' => true,
							),
						),
						'default'    => 'default',
						'dependency' => array( 'pdt_layout_preset', 'any', 'carousel_layout,grid_layout,filter_layout,large_with_small', true ),
					),
					array(
						'id'         => 'overlay_position',
						'type'       => 'select',
						'title'      => esc_html__( 'Overlay Position ', 'productify-pro' ),
						'subtitle'   => esc_html__( 'Set a position for the overlay item content.', 'productify-pro' ),
						'options'    => array(
							'content_top'      => esc_html__( 'Content Top', 'productify-pro' ),
							'content_center'   => esc_html__( 'Content Center', 'productify-pro' ),
							'content_bottom'   => esc_html__( 'Content Bottom', 'productify-pro' ),
							'content_on_hover' => esc_html__( 'Content On Hover', 'productify-pro' ),
						),
						'attributes' => array(
							'style' => 'width: 200px;',
						),
						'default'    => 'content_bottom',
						'dependency' => array( 'post_content_orientation', '==', 'overlay', true ),
					),
					array(
						'id'         => 'item_same_height',
						'type'       => 'checkbox',
						'title'      => esc_html__( 'Same Height', 'productify-pro' ),
						'subtitle'   => esc_html__( 'Check to make all items/slides the same height as the tallest one.', 'productify-pro' ),
						'default'    => false,
						'dependency' => array( 'pdt_layout_preset', 'any', 'carousel_layout,grid_layout,filter_layout,large_with_small', true ),
					),
					array(
						'id'         => 'post_list_orientation',
						'type'       => 'layout_preset',
						'class'      => 'img_custom_width',
						'title'      => esc_html__( 'Content Orientation ', 'productify-pro' ),
						'subtitle'   => esc_html__( 'Set a position for the post content.', 'productify-pro' ),
						'options'    => array(
							'left-thumb'  => array(
								'image' => PDT_URL . 'admin/views/ta-framework/assets/img/left-image.svg',
								'text'  => esc_html__( 'Left Image', 'productify-pro' ),
							),
							'right-thumb' => array(
								'image' => PDT_URL . 'admin/views/ta-framework/assets/img/right-image.svg',
								'text'  => esc_html__( 'Right Image', 'productify-pro' ),
							),
						),
						'default'    => 'left-thumb',
						'dependency' => array( 'pdt_layout_preset', '==', 'list_layout', true ),
					),
					array(
						'id'       => 'post_border',
						'type'     => 'border',
						'title'    => esc_html__( 'Border', 'productify-pro' ),
						'subtitle' => esc_html__( 'Set border for the item.', 'productify-pro' ),
						'all'      => true,
						'default'  => array(
							'all'   => '0',
							'style' => 'solid',
							'color' => '#e2e2e2',
						),
					),
					array(
						'id'       => 'post_border_radius_property',
						'type'     => 'spacing',
						'title'    => esc_html__( 'Border Radius', 'productify-pro' ),
						'subtitle' => esc_html__( 'Set border radius for item.', 'productify-pro' ),
						'all'      => true,
						'units'    => array( 'px', '%' ),
						'default'  => array(
							'all' => '0',
						),
					),
					array(
						'id'       => 'show_post_box_shadow',
						'type'     => 'checkbox',
						'title'    => esc_html__( 'Box-Shadow', 'productify-pro' ),
						'subtitle' => esc_html__( 'Show box-shadow for the item.', 'productify-pro' ),
						'default'  => false,
					),
					array(
						'id'         => 'post_box_shadow_property',
						'type'       => 'box_shadow',
						'title'      => esc_html__( 'Box-Shadow Values', 'productify-pro' ),
						'subtitle'   => esc_html__( 'Set box-shadow property values for the item.', 'productify-pro' ),
						'default'    => array(
							'horizontal' => '0',
							'vertical'   => '0',
							'blur'       => '8',
							'spread'     => '-2',
							'color'      => 'rgb(187, 187, 187)',
						),
						'dependency' => array( 'show_post_box_shadow', '==', 'true' ),
					),
					array(
						'id'         => 'post_background_property',
						'type'       => 'color',
						'title'      => esc_html__( 'Background', 'productify-pro' ),
						'subtitle'   => esc_html__( 'Set background color for the item.', 'productify-pro' ),
						'default'    => '#ffffff',
						'dependency' => array( 'post_content_orientation', '!=', 'overlay' ),
					),
					array(
						'id'         => 'post_background_overlay',
						'type'       => 'color',
						'title'      => esc_html__( 'Background', 'productify-pro' ),
						'subtitle'   => esc_html__( 'Set background color for the item.', 'productify-pro' ),
						'default'    => '#14141F',
						'dependency' => array( 'post_content_orientation', '==', 'overlay' ),
					),
					array(
						'id'         => 'post_background_blur',
						'type'       => 'slider',
						'title'      => esc_html__( 'Slider', 'productify-pro' ),
						'min'        => 0,
						'max'        => 9,
						'step'       => 1,
						'unit'       => '',
						'default'    => 7,
						'dependency' => array( 'post_content_orientation', '==', 'overlay' ),
					),

					array(
						'id'       => 'post_inner_padding_property',
						'type'     => 'spacing',
						'title'    => esc_html__( 'Inner Padding', 'productify-pro' ),
						'subtitle' => esc_html__( 'Set inner padding for  item.', 'productify-pro' ),
						'default'  => array(
							'top'    => '0',
							'right'  => '0',
							'bottom' => '0',
							'left'   => '0',
							'unit'   => 'px',
						),
						'help'     => "<img src='" . PDT_URL . "/admin/assets/img/inner_padding.jpg'>",
					),
					array(
						'id'       => 'post_content_sorter',
						'type'     => 'sortable',
						'title'    => esc_html__( 'Content Fields', 'productify-pro' ),
						'subtitle' => esc_html__( 'Item content fields which are draggable to change display order and it\'s settings.', 'productify-pro' ),
						'class'    => 'post_content_sorter',
						'fields'   => array(
							array(
								'id'         => 'pdt_product_thumb',
								'type'       => 'accordion',
								'accordions' => array(
									array(
										'title'  => esc_html__( 'Thumbnail', 'productify-pro' ),
										'fields' => array(
											array(
												'id'       => 'post_thumb_show',
												'type'     => 'switcher',
												'title'    => esc_html__( 'Thumbnail', 'productify-pro' ),
												'text_on'  => esc_html__( 'Show', 'productify-pro' ),
												'text_off' => esc_html__( 'Hide', 'productify-pro' ),
												'default'  => true,
												'text_width' => 80,
											),
											array(
												'id'      => 'pdt_thumb_sizes',
												'type'    => 'image_sizes',
												'title'   => esc_html__( 'Size', 'productify-pro' ),
												'default' => 'full',
												'dependency' => array( 'post_thumb_show', '==', 'true', true ),
											),
											array(
												'id'       => 'pdt_image_crop_size',
												'type'     => 'dimensions_advanced',
												'title'    => esc_html__( 'Custom Size', 'productify-pro' ),
												'chosen'   => true,
												'bottom'   => false,
												'left'     => false,
												'color'    => false,
												'top_icon' => '<i class="fas fa-arrows-h"></i>',
												'right_icon' => '<i class="fas fa-arrows-v"></i>',
												'top_placeholder' => 'width',
												'right_placeholder' => 'height',
												'styles'   => array(
													'Soft-crop',
													'Hard-crop',
												),
												'default'  => array(
													'top'  => '600',
													'right' => '400',
													'style' => esc_html__( 'Soft-crop', 'productify-pro' ),
													'unit' => 'px',
												),
												'attributes' => array(
													'min' => 0,
												),
												'dependency' => array( 'post_thumb_show|pdt_thumb_sizes', '==|==', 'true|custom' ),
											),
											array(
												'id'       => 'load_2x_image',
												'type'     => 'switcher',
												'title'    => esc_html__( 'Load 2x Resolution Image in Retina Display', 'productify-pro' ),
												'text_on'  => esc_html__( 'Enabled', 'productify-pro' ),
												'text_off' => esc_html__( 'Disabled', 'productify-pro' ),
												'text_width' => 94,
												'default'  => false,
												'dependency' => array( 'post_thumb_show|pdt_thumb_sizes', '==|==', 'true|custom' ),
											),
											array(
												'id'       => 'post_thumb_margin',
												'type'     => 'spacing',
												'title'    => esc_html__( 'Margin', 'productify-pro' ),
												'sanitize' => 'pdt_sanitize_number_array_field',
												'units'    => array( 'px' ),
												'min'      => -100,
												'default'  => array(
													'top'  => '0',
													'right' => '0',
													'bottom' => '20',
													'left' => '0',
												),
												'dependency' => array( 'post_thumb_show', '==', 'true' ),
											),
											array(
												'id'      => 'pdt_thumb_src_replace',
												'type'    => 'checkbox',
												'title'   => esc_html__( 'Replace With', 'productify-pro' ),
												'class'   => 'custom_help_text',
												'title_help' => esc_html__( 'This option will replace your default/featured post image with first resource ( image/video/audio ) from the content.', 'productify-pro' ),
												'options' => array(
													'image'   => esc_html__( 'Image', 'productify-pro' ),
													'video'   => esc_html__( 'Video', 'productify-pro' ),
													'audio'   => esc_html__( 'Audio', 'productify-pro' ),
												),
												'dependency' => array( 'post_thumb_show', '==', 'true' ),
											),
											array(
												'id'      => 'post_featured_thumb_found',
												'type'    => 'select',
												'title'   => ' ',
												'options' => array(
													'no_featured_img_found' => esc_html__( 'If no featured image found', 'productify-pro' ),
													'even_featured_img_found' => esc_html__( 'Even featured image was found', 'productify-pro' ),
												),
												'default' => 'no_featured_img_found',
												'dependency' => array( 'post_thumb_show|pdt_thumb_src_replace', '==|any', 'true|image,video,audio' ),
											),

											array(
												'id'      => 'pdt_thumb_border',
												'type'    => 'border',
												'title'   => esc_html__( 'Border', 'productify-pro' ),
												'all'     => true,
												'default' => array(
													'all' => '0',
													'style' => 'solid',
													'color' => '#dddddd',
												),
												'dependency' => array( 'post_thumb_show', '==', 'true' ),
											),
											array(
												'id'       => 'post_thumb_border_radius',
												'type'     => 'spacing',
												'title'    => esc_html__( 'Border Radius', 'productify-pro' ),
												'sanitize' => 'pdt_sanitize_number_array_field',
												'default'  => array(
													'top'  => '0',
													'right' => '0',
													'bottom' => '0',
													'left' => '0',
													'unit' => 'px',
												),
												'dependency' => array( 'post_thumb_show', '==', 'true' ),
											),

											array(
												'id'      => 'post_thumb_zoom',
												'type'    => 'select',
												'title'   => esc_html__( 'Zoom Effect', 'productify-pro' ),
												'options' => array(
													'none' => esc_html__( 'None', 'productify-pro' ),
													'zoom_in' => esc_html__( 'Zoom In', 'productify-pro' ),
													'zoom_out' => esc_html__( 'Zoom Out', 'productify-pro' ),
												),
												'default' => 'none',
												'dependency' => array( 'post_thumb_show', '==', 'true' ),
											),
											array(
												'id'      => 'post_thumb_gray_scale',
												'type'    => 'select',
												'title'   => esc_html__( 'Image Mode', 'productify-pro' ),
												'options' => array(
													'none' => esc_html__( 'Normal', 'productify-pro' ),
													'gray_and_normal' => esc_html__( 'Grayscale and normal on hover', 'productify-pro' ),
													'gray_on_hover' => esc_html__( 'Grayscale on hover', 'productify-pro' ),
													'always_gray' => esc_html__( 'Always grayscale', 'productify-pro' ),
												),
												'default' => 'none',
												'dependency' => array( 'post_thumb_show', '==', 'true' ),
											),
											array(
												'id'       => 'pdt_img_lazy_load',
												'type'     => 'switcher',
												'class'    => 'custom_help_text',
												'title'    => esc_html__( 'Lazy Load', 'productify-pro' ),
												'title_help' => esc_html__( 'Defer image loading to improve performance.', 'productify-pro' ),
												'default'  => true,
												'text_on'  => esc_html__( 'Enabled', 'productify-pro' ),
												'text_off' => esc_html__( 'Disabled', 'productify-pro' ),
												'text_width' => 100,
												'dependency' => array( 'post_thumb_show|pdt_layout_preset', '==|!=', 'true|carousel_layout', true ),
											),
											array(
												'id'      => 'post_thumb_meta',
												'type'    => 'button_set',
												'title'   => esc_html__( 'Show Product Thumb Meta', 'productify-pro' ),
												'default' => true,
												'options' => array(
													'category' => esc_html__( 'Category', 'productify-pro' ),
													'date' => esc_html__( 'Date', 'productify-pro' ),
													'on_sale' => esc_html__( 'On Sale', 'productify-pro' ),
													'none' => esc_html__( 'None', 'productify-pro' ),
												),
												'default' => 'none',
												'dependency' => array( 'post_thumb_show', '==', 'true' ),
											),
											array(
												'id'      => 'post_thumb_meta_taxonomy',
												'type'    => 'select',
												'title'   => esc_html__( 'Select Taxonomy', 'productify-pro' ),
												'options' => 'taxonomy',
												'query_args' => array(
													'type' => 'product',
												),
												'attributes' => array(
													'style' => 'width: 200px;',
												),
												'empty_message' => esc_html__( 'No taxonomies found.', 'productify-pro' ),
												'dependency' => array( 'post_thumb_show|post_thumb_meta', '==|==', 'true|category' ),
											),
											array(
												'id'      => 'post_thumb_meta_date_format',
												'type'    => 'select',
												'title'   => esc_html__( 'Date Format', 'productify-pro' ),
												'options' => array(
													'default' => esc_html__( 'Default', 'productify-pro' ),
													'time_ago' => esc_html__( 'Time ago(human time)', 'productify-pro' ),
													'custom' => esc_html__( 'Custom', 'productify-pro' ),
												),
												'default' => 'default',
												'dependency' => array( 'select_post_meta', '==', 'date' ),
											),
											array(
												'id'       => 'post_thumb_meta_position',
												'type'     => 'select',
												'title'    => esc_html__( 'Taxonomy Position', 'productify-pro' ),
												'subtitle' => esc_html__( 'Select a position for the navigation arrows.', 'productify-pro' ),
												'options'  => array(
													'top_right'                   => esc_html__( 'Top right', 'productify-pro' ),
													'top_center'                  => esc_html__( 'Top center', 'productify-pro' ),
													'top_left'                    => esc_html__( 'Top left', 'productify-pro' ),
													'bottom_left'                 => esc_html__( 'Bottom left', 'productify-pro' ),
													'bottom_center'               => esc_html__( 'Bottom center', 'productify-pro' ),
													'bottom_right'                => esc_html__( 'Bottom right', 'productify-pro' ),
												),
												'default'  => 'top_right',
												'dependency' => array( 'post_thumb_show|post_thumb_meta', '==|!=', 'true|none' ),
											),

											array(
												'id'      => 'post_thumb_meta_button',
												'type'    => 'color_group',
												'title'   => esc_html__( 'Button Color', 'productify-pro' ),
												'options' => array(
													'standard' => esc_html__( 'Text Color', 'productify-pro' ),
													'hover' => esc_html__( 'Text Hover Color', 'productify-pro' ),
													'bg' => esc_html__( 'Background', 'productify-pro' ),
													'hover_bg' => esc_html__( 'Hover Background', 'productify-pro' ),
													'border' => esc_html__( 'Border', 'productify-pro' ),
													'hover_border' => esc_html__( 'Hover Border', 'productify-pro' ),
												),
												'default' => array(
													'standard' => '#ffffff',
													'hover' => '#ffffff',
													'bg' => '#934899',
													'hover_bg' => '#bf21cc',
													'border' => '#934899',
													'hover_border' => '#bf21cc',
												),
												'dependency' => array( 'post_thumb_show|post_thumb_meta', '==|!=', 'true|none' ),
											),
										),
									),
								),
							),
							array(
								'id'         => 'pdt_product_title',
								'type'       => 'accordion',
								'accordions' => array(
									array(
										'title'  => esc_html__( 'Title', 'productify-pro' ),
										'fields' => array(
											array(
												'id'       => 'show_post_title',
												'type'     => 'switcher',
												'title'    => esc_html__( 'Title', 'productify-pro' ),
												'text_on'  => esc_html__( 'Show', 'productify-pro' ),
												'text_off' => esc_html__( 'Hide', 'productify-pro' ),
												'default'  => true,
												'text_width' => 80,
											),
											array(
												'id'      => 'post_title_tag',
												'type'    => 'select',
												'title'   => esc_html__( 'Title HTML Tag', 'productify-pro' ),
												'options' => array(
													'h1'  => esc_html__( 'h1', 'productify-pro' ),
													'h2'  => esc_html__( 'h2', 'productify-pro' ),
													'h3'  => esc_html__( 'h3', 'productify-pro' ),
													'h4'  => esc_html__( 'h4', 'productify-pro' ),
													'h5'  => esc_html__( 'h5', 'productify-pro' ),
													'h6'  => esc_html__( 'h6', 'productify-pro' ),
													'p'   => esc_html__( 'p', 'productify-pro' ),
													'div' => esc_html__( 'div', 'productify-pro' ),
												),
												'default' => 'h2',
												'class'   => 'chosen',
												'dependency' => array( 'show_post_title', '==', 'true', true ),
											),
											array(
												'id'      => 'post_title_limit',
												'type'    => 'checkbox',
												'title'   => esc_html__( 'Limit Character', 'productify-pro' ),
												'default' => false,
												'dependency' => array( 'show_post_title', '==', 'true' ),
											),
											array(
												'id'       => 'pdt_title_length',
												'type'     => 'spinner',
												'title'    => esc_html__( 'Length', 'productify-pro' ),
												'default'  => '30',
												'sanitize' => 'pdt_sanitize_number_field',
												'unit'     => esc_html__( 'chars', 'productify-pro' ),
												'dependency' => array( 'post_title_limit|show_post_title', '==|==', 'true|true' ),
											),
											array(
												'id'       => 'post_title_margin',
												'type'     => 'spacing',
												'title'    => esc_html__( 'Margin', 'productify-pro' ),
												'sanitize' => 'pdt_sanitize_number_array_field',
												'min'      => -100,
												'units'    => array( 'px' ),
												'default'  => array(
													'top'  => '0',
													'right' => '0',
													'bottom' => '20',
													'left' => '0',
												),
												'dependency' => array( 'show_post_title', '==', 'true' ),
											),
										),
									),
								),
							),

							array(
								'id'         => 'pdt_product_meta',
								'class'      => 'pdt_product_meta ta-product-not-fields',
								'type'       => 'accordion',
								'accordions' => array(
									array(
										'title'  => esc_html__( 'Meta Fields', 'productify-pro' ),
										'fields' => array(
											array(
												'id'       => 'show_post_meta',
												'type'     => 'switcher',
												'title'    => esc_html__( 'Meta Fields', 'productify-pro' ),
												'text_on'  => esc_html__( 'Show', 'productify-pro' ),
												'text_off' => esc_html__( 'Hide', 'productify-pro' ),
												'default'  => false,
												'text_width' => 80,
											),
											array(
												'id'      => 'pdt_product_meta_group',
												'class'   => 'pdt_custom_group_design',
												'type'    => 'group',
												'button_title' => esc_html__( 'Add New Meta', 'productify-pro' ),
												'dependency' => array( 'show_post_meta', '==', 'true' ),
												'fields'  => array(
													array(
														'id'       => 'select_post_meta',
														'class'       => 'select_post_meta',
														'type'     => 'select',
														'title'    => esc_html__( 'Select Meta', 'productify-pro' ),
														'placeholder' => esc_html__( 'Select a meta', 'productify-pro' ),
														'options'  => array(
															'date'   => esc_html__( 'Date', 'productify-pro' ),
															'taxonomy'   => esc_html__( 'Taxonomy', 'productify-pro' ),
															'comment_count'  => esc_html__( 'Comment Count', 'productify-pro' ),
															'view_count' => esc_html__( 'View Count', 'productify-pro' ),
															'like'     => esc_html__( 'Like', 'productify-pro' ),
														),
													),
													array(
														'id'      => 'post_meta_date_format',
														'type'    => 'select',
														'title'   => esc_html__( 'Date Format', 'productify-pro' ),
														'class'   => 'post_meta_date_format',
														'options' => array(
															'default' => esc_html__( 'Default', 'productify-pro' ),
															'time_ago' => esc_html__( 'Time ago(human time)', 'productify-pro' ),
															'custom' => esc_html__( 'Custom', 'productify-pro' ),
														),
														'default' => 'default',
														'dependency' => array( 'select_post_meta', '==', 'date' ),
													),
													array(
														'id'    => 'pdt_custom_meta_date_format',
														'type'  => 'text',
														'title' => ' ',
														'class' => 'pdt_custom_meta_date_format',
														'placeholder' => esc_html__( 'F j, Y', 'productify-pro' ),
														'default'   => esc_html__( 'F j, Y', 'productify-pro' ),
														'desc' => __( 'To define format, check <a href="https://wordpress.org/support/article/formatting-date-and-time/" target="_blank" rel="noopener noreferrer nofollow"><em>this doc</em></a>.', 'productify-pro' ),
														'dependency' => array( 'select_post_meta|post_meta_date_format', '==|==', 'date|custom' ),
													),
													array(
														'id'      => 'post_meta_taxonomy',
														'type'    => 'select',
														'title'   => esc_html__( 'Select Taxonomy', 'productify-pro' ),
														'class'   => 'post_meta_taxonomy',
														'options' => 'taxonomy',
														'query_args' => array(
															'type' => 'post',
														),
														'attributes' => array(
															'style' => 'width: 200px;',
														),
														'empty_message' => esc_html__( 'No taxonomies found.', 'productify-pro' ),
														'dependency' => array( 'select_post_meta', '==', 'taxonomy' ),
													),
													array(
														'id'      => 'pdt_meta_position',
														'class'      => 'pdt_meta_position',
														'type'    => 'button_set',
														'title'   => esc_html__( 'Position', 'productify-pro' ),
														'options' => array(
															'beside_meta' => esc_html__( 'Beside Other Meta', 'productify-pro' ),
															'above_title' => esc_html__( 'Above Title', 'productify-pro' ),
															'over_thumb' => esc_html__( 'Over Thumbnail', 'productify-pro' ),

														),
														'default' => 'beside_meta',
														'dependency' => array( 'select_post_meta', '==', 'taxonomy' ),
													),
													array(
														'id'      => 'pdt_meta_over_thump_position',
														'type'    => 'select',
														'title'   => esc_html__( 'Over Thumbnail Position', 'productify-pro' ),
														'options' => array(
															'top_left' => esc_html__( 'Top Left', 'productify-pro' ),
															'top_right' => esc_html__( 'Top Right', 'productify-pro' ),
															'bottom_left' => esc_html__( 'Bottom Left', 'productify-pro' ),
															'bottom_right' => esc_html__( 'Bottom Right', 'productify-pro' ),
														),
														'default' => 'top_left',
														'dependency' => array( 'select_post_meta|pdt_meta_position', '==|==', 'taxonomy|over_thumb' ),
													),
													array(
														'id'      => 'pdt_meta_pill_color',
														'type'    => 'color_group',
														'title'   => esc_html__( 'Meta Color', 'productify-pro' ),
														'options' => array(
															'text' => esc_html__( 'Text', 'productify-pro' ),
															'bg' => esc_html__( 'Background', 'productify-pro' ),
														),
														'default' => array(
															'text' => '#fff',
															'bg' => '#e53935',
														),
														'dependency' => array( 'select_post_meta|pdt_meta_position', '==|!=', 'taxonomy|beside_meta' ),
													),
													array(
														'id'      => 'select_meta_icon',
														'class'      => 'select_meta_icon',
														'type'    => 'icon',
														'title'   => esc_html__( 'Meta Icon', 'productify-pro' ),
														'default' => 'far fa-folder',
														'dependency' => array( 'pdt_meta_position|select_post_meta', '==|!=', 'beside_meta|like' ),
													),
												),
												'default' => array(
													array(
														'select_post_meta'     => 'date',
														'select_meta_icon'    => 'fas fa-calendar',
														'pdt_meta_position'     => 'beside_meta',
													),
													array(
														'select_post_meta'     => 'comment_count',
														'select_meta_icon'    => 'fas fa-calendar-alt',
														'pdt_meta_position'     => 'beside_meta',
													),
												),
											),
											array(
												'id'      => 'meta_separator',
												'type'    => 'radio',
												'title'   => esc_html__( 'Meta Separator', 'productify-pro' ),
												'options' => array(
													' '  => esc_html__( 'Normal Space ', 'productify-pro' ),
													'. ' => esc_html__( 'Full Stop ( . ) ', 'productify-pro' ),
													'| ' => esc_html__( 'Straight Line ( | )', 'productify-pro' ),
													'/ ' => esc_html__( 'Slash ( / )', 'productify-pro' ),
													'\ ' => esc_html__( 'Back Slash( \\ )', 'productify-pro' ),
												),
												'default' => ' ',
												'dependency' => array( 'show_post_meta', '==', 'true' ),
											),
											array(
												'id'      => 'meta_separator_color',
												'type'    => 'color',
												'title'   => esc_html__( 'Meta Separator Color', 'productify-pro' ),
												'default' => '#934899',
												'dependency' => array( 'show_post_meta', '==', 'true' ),
											),
											array(
												'id'      => 'post_meta_alignment',
												'type'    => 'button_set',
												'title'   => esc_html__( 'Alignment', 'productify-pro' ),
												'options' => array(
													'left' => wp_kses( __( '<i class="fas fa-align-left" title="Left"></i>', 'productify-pro' ), array( 'i' => array( 'class' => array() ) ) ),
													'center' => wp_kses( __( '<i class="fas fa-align-center" title="Center"></i>', 'productify-pro' ), array( 'i' => array( 'class' => array() ) ) ),
													'right' => wp_kses( __( '<i class="fas fa-align-right" title="Right"></i>', 'productify-pro' ), array( 'i' => array( 'class' => array() ) ) ),
												),
												'default' => 'left',
												'dependency' => array( 'show_post_meta', '==', 'true' ),
											),
											array(
												'id'       => 'post_meta_margin',
												'type'     => 'spacing',
												'title'    => esc_html__( 'Margin', 'productify-pro' ),
												'sanitize' => 'pdt_sanitize_number_array_field',
												'units'    => array( 'px' ),
												'min'      => -100,
												'dependency' => array( 'show_post_meta', '==', 'true' ),
												'default'  => array(
													'top'  => '0',
													'right' => '0',
													'bottom' => '20',
													'left' => '0',
												),
											),
											array(
												'id'       => 'post_meta_between_margin',
												'type'     => 'spacing',
												'title'    => esc_html__( 'Margin Between Post Meta', 'productify-pro' ),
												'sanitize' => 'pdt_sanitize_number_array_field',
												'units'    => array( 'px' ),
												'min'      => -5,
												'dependency' => array( 'show_post_meta', '==', 'true' ),
												'default'  => array(
													'top'  => '0',
													'right' => '0',
													'bottom' => '0',
													'left' => '0',
												),
											),
										),
									),
								),
							),
							array(
								'id'         => 'pdt_product_content',
								'type'       => 'accordion',
								'accordions' => array(
									array(
										'title'  => esc_html__( 'Content', 'productify-pro' ),
										'fields' => array(
											array(
												'id'       => 'show_post_content',
												'type'     => 'switcher',
												'title'    => esc_html__( 'Content', 'productify-pro' ),
												'text_on'  => esc_html__( 'Show', 'productify-pro' ),
												'text_off' => esc_html__( 'Hide', 'productify-pro' ),
												'default'  => true,
												'text_width' => 80,
											),
											array(
												'id'      => 'post_content_type',
												'type'    => 'select',
												'title'   => esc_html__( 'Content Display Type', 'productify-pro' ),
												'options' => array(
													'excerpt'      => esc_html__( 'Excerpt', 'productify-pro' ),
													'limit_content' => esc_html__( 'Content with Limit', 'productify-pro' ),
													'full_content' => esc_html__( 'Full Content', 'productify-pro' ),
												),
												'default' => 'limit_content',
												'dependency' => array( 'show_post_content', '==', 'true' ),
											),
											array(
												'id'      => 'pdt_content_length_type',
												'type'    => 'button_set',
												'title'   => esc_html__( 'Content Length Type', 'productify-pro' ),
												'options' => array(
													'words'    => esc_html__( 'Words', 'productify-pro' ),
													'characters' => esc_html__( 'Characters', 'productify-pro' ),
												),
												'default' => 'words',
												'dependency' => array( 'show_post_content|post_content_type', '==|==', 'true|limit_content' ),
											),
											array(
												'id'       => 'pdt_content_limit',
												'type'     => 'spinner',
												'title'    => esc_html__( 'Words Length', 'productify-pro' ),
												'sanitize' => 'pdt_sanitize_number_field',
												'default'  => 30,
												'max'      => 10000,
												'dependency' => array( 'show_post_content|post_content_type|pdt_content_length_type', '==|==|==', 'true|limit_content|words' ),
											),
											array(
												'id'       => 'pdt_content_characters_limit',
												'type'     => 'spinner',
												'title'    => esc_html__( 'Characters Length', 'productify-pro' ),
												'sanitize' => 'pdt_sanitize_number_field',
												'default'  => 300,
												'max'      => 10000,
												'dependency' => array( 'show_post_content|post_content_type|pdt_content_length_type', '==|==|==', 'true|limit_content|characters' ),
											),
											array(
												'id'       => 'post_content_margin',
												'type'     => 'spacing',
												'title'    => esc_html__( 'Margin', 'productify-pro' ),
												'sanitize' => 'pdt_sanitize_number_array_field',
												'units'    => array( 'px' ),
												'min'      => -100,
												'default'  => array(
													'top'  => '0',
													'right' => '0',
													'bottom' => '20',
													'left' => '0',
												),
												'dependency' => array( 'show_post_content', '==', 'true' ),
											),
											array(
												'id'      => 'pdt_strip_tags',
												'type'    => 'radio',
												'title'   => esc_html__( 'HTML Tags', 'productify-pro' ),
												'options' => array(
													'allow_all'  => esc_html__( 'Allow All', 'productify-pro' ),
													'strip_all'  => esc_html__( 'Strip All', 'productify-pro' ),
													'allow_some' => esc_html__( 'Allow Some', 'productify-pro' ),
												),
												'default' => 'allow_all',
												'dependency' => array( 'show_post_content|post_content_type', '==|!=', 'true|excerpt' ),
											),
											array(
												'id'    => 'pdt_allow_tag_name',
												'type'  => 'text',
												'title' => esc_html__( 'Allow HTML Tags Names', 'productify-pro' ),
												'title_help' => esc_html__( 'Separate multiple tags by comma, e.g. h1,h2', 'productify-pro' ),
												'dependency' => array( 'show_post_content|pdt_strip_tags', '==|==', 'true|allow_some' ),
											),
											array(
												'id'      => 'post_content_ellipsis',
												'type'    => 'text',
												'title'   => esc_html__( 'Ellipsis Points Ending Excerpt', 'productify-pro' ),
												'default' => '...',
												'dependency' => array( 'show_post_content|post_content_type', '==|!=', 'true|full_content' ),
											),
										),
									),
								),
							),
							array(
								'id'         => 'pdt_product_price',
								'class'      => 'pdt_product_price',
								'type'       => 'accordion',
								'accordions' => array(
									array(
										'title'  => esc_html__( 'Product Price', 'productify-pro' ),
										'fields' => array(
											array(
												'id'       => 'product_price',
												'type'     => 'switcher',
												'title'    => __( 'Price', 'productify-pro' ),
												'subtitle' => __( 'Show/Hide product price.', 'productify-pro' ),
												'text_on'  => __( 'Show', 'productify-pro' ),
												'text_off' => __( 'Hide', 'productify-pro' ),
												'text_width' => 77,
												'default'  => true,
											),
											array(
												'id'       => 'product_del_price_color',
												'type'     => 'color',
												'title'    => __( 'Discount Color', 'productify-pro' ),
												'subtitle' => __( 'Set discount price color.', 'productify-pro' ),
												'default'  => '#888888',
												'dependency' => array( 'product_price', '==', 'true' ),
											),
											array(
												'id'       => 'product_fildes_margin',
												'type'     => 'spacing',
												'title'    => esc_html__( 'Margin', 'productify-pro' ),
												'sanitize' => 'pdt_sanitize_number_array_field',
												'units'    => array( 'px' ),
												'min'      => -100,
												'dependency' => array( 'product_price', '==', 'true' ),
												'default'  => array(
													'top'  => '0',
													'right' => '0',
													'bottom' => '15',
													'left' => '0',
												),
											),
										),
									),
								),
							),
							array(
								'id'         => 'pdt_product_rating',
								'type'       => 'accordion',
								'accordions' => array(
									array(
										'title'  => esc_html__( 'Product Rating', 'productify-pro' ),
										'fields' => array(
											array(
												'id'       => 'product_rating',
												'type'     => 'switcher',
												'title'    => esc_html__( 'Rating', 'productify-pro' ),
												'text_on'  => esc_html__( 'Show', 'productify-pro' ),
												'text_off' => esc_html__( 'Hide', 'productify-pro' ),
												'text_width' => 77,
												'default'  => true,
											),
											array(
												'id'      => 'product_rating_position',
												'type'    => 'button_set',
												'title'   => esc_html__( 'Alignment', 'productify-pro' ),
												'options' => array(
													'left' => wp_kses( __( '<i class="fas fa-align-left" title="Left"></i>', 'productify-pro' ), array( 'i' => array( 'class' => array() ) ) ),
													'center' => wp_kses( __( '<i class="fas fa-align-center" title="Center"></i>', 'productify-pro' ), array( 'i' => array( 'class' => array() ) ) ),
													'right' => wp_kses( __( '<i class="fas fa-align-right" title="Right"></i>', 'productify-pro' ), array( 'i' => array( 'class' => array() ) ) ),
												),
												'default' => 'left',
												'dependency' => array( 'product_rating', '==', 'true' ),
											),
											array(
												'id'      => 'product_rating_colors',
												'type'    => 'color_group',
												'title'   => esc_html__( 'Color', 'productify-pro' ),
												'options' => array(
													'color'       => esc_html__( 'Star Color', 'productify-pro' ),
													'empty_color' => esc_html__( 'Empty Star Color', 'productify-pro' ),
												),
												'default' => array(
													'color'       => '#F4C100',
													'empty_color' => '#C8C8C8',
												),
												'dependency' => array( 'product_rating', '==', 'true' ),
											),
											array(
												'id'       => 'product_rating_margin',
												'type'     => 'spacing',
												'title'    => esc_html__( 'Margin', 'productify-pro' ),
												'sanitize' => 'pdt_sanitize_number_array_field',
												'units'    => array( 'px' ),
												'min'      => -100,
												'dependency' => array( 'product_rating', '==', 'true' ),
												'default'  => array(
													'top'  => '0',
													'right' => '0',
													'bottom' => '15',
													'left' => '0',
												),
											),
										),
									),
								),
							),
							array(
								'id'         => 'pdt_product_content_button',
								'type'       => 'accordion',
								'accordions' => array(
									array(
										'title'  => esc_html__( 'Button', 'productify-pro' ),
										'fields' => array(
											// ReadMore settings.
											array(
												'id'       => 'show_button',
												'type'     => 'switcher',
												'title'    => esc_html__( 'Button', 'productify-pro' ),
												'text_on'  => esc_html__( 'Show', 'productify-pro' ),
												'text_off' => esc_html__( 'Hide', 'productify-pro' ),
												'default'  => true,
												'text_width' => 80,
											),
											array(
												'id'      => 'button_type',
												'type'    => 'button_set',
												'title'   => esc_html__( 'Button Type', 'productify-pro' ),
												'options' => array(
													'add_to_cart'    => esc_html__( 'Add To Cart', 'productify-pro' ),
													'button'    => esc_html__( 'Read More', 'productify-pro' ),
													'text_link' => esc_html__( 'Read More Text Link', 'productify-pro' ),
												),
												'default' => 'add_to_cart',
												'dependency' => array( 'show_button', '==', 'true' ),
											),
											array(
												'id'      => 'pdt_read_label',
												'type'    => 'text',
												'title'   => esc_html__( 'Button Label', 'productify-pro' ),
												'default' => __( 'Read More', 'productify-pro' ),
												'dependency' => array( 'show_button|button_type', '==|==', 'true|button' ),
											),
											array(
												'id'      => 'button_color_button',
												'type'    => 'color_group',
												'title'   => esc_html__( 'Button Color', 'productify-pro' ),
												'options' => array(
													'standard' => esc_html__( 'Text Color', 'productify-pro' ),
													'hover' => esc_html__( 'Text Hover Color', 'productify-pro' ),
													'bg' => esc_html__( 'Background', 'productify-pro' ),
													'hover_bg' => esc_html__( 'Hover Background', 'productify-pro' ),
													'border' => esc_html__( 'Border', 'productify-pro' ),
													'hover_border' => esc_html__( 'Hover Border', 'productify-pro' ),
												),
												'default' => array(
													'standard' => '#ffffff',
													'hover' => '#ffffff',
													'bg' => '#934899',
													'hover_bg' => '#bf21cc',
													'border' => '#934899',
													'hover_border' => '#bf21cc',
												),
												'dependency' => array( 'show_button|button_type', '==|!=', 'true|text_link' ),
											),
											array(
												'id'    => 'button_border',
												'type'  => 'border',
												'title' => esc_html__( 'Border', 'productify-pro' ),
												'all'   => true,
												'color' => false,
												'dependency' => array( 'show_button|button_type', '==|!=', 'true|text_link' ),
											),
											array(
												'id'       => 'button_padding',
												'type'     => 'spacing',
												'title'    => esc_html__( 'Padding', 'productify-pro' ),
												'sanitize' => 'pdt_sanitize_number_array_field',
												'units'    => array( 'px' ),
												'min'      => -100,
												'default'  => array(
													'top'  => '6',
													'right' => '20',
													'bottom' => '6',
													'left' => '20',
												),
												'dependency' => array( 'show_button|button_type', '==|!=', 'true|text_link' ),
											),
											array(
												'id'       => 'button_margin',
												'type'     => 'spacing',
												'title'    => esc_html__( 'Margin', 'productify-pro' ),
												'sanitize' => 'pdt_sanitize_number_array_field',
												'units'    => array( 'px' ),
												'min'      => -100,
												'default'  => array(
													'top'  => '0',
													'right' => '0',
													'bottom' => '15',
													'left' => '0',
												),
												'dependency' => array( 'show_button', '==', 'true' ),
											),
											array(
												'id'       => 'button_button_radius',
												'type'     => 'spacing',
												'title'    => esc_html__( 'Border Radius', 'productify-pro' ),
												'sanitize' => 'pdt_sanitize_number_array_field',
												'all'      => true,
												'default'  => array(
													'all'  => '0',
													'unit' => 'px',
												),
												'units'    => array( 'px', '%' ),
												'dependency' => array( 'show_button|button_type', '==|!=', 'true|text_link' ),
											),
											array(
												'id'      => 'button_color_text',
												'type'    => 'color_group',
												'title'   => esc_html__( 'Button Color', 'productify-pro' ),
												'options' => array(
													'standard' => esc_html__( 'Text Color', 'productify-pro' ),
													'hover' => esc_html__( 'Text Hover Color', 'productify-pro' ),
												),
												'default' => array(
													'standard' => '#ffffff',
													'hover' => '#934899',
												),
												'dependency' => array( 'show_button|button_type', '==|==', 'true|text_link' ),
											),

										),
									),
								),
							),
							array(
								'id'         => 'pdt_social_share',
								'type'       => 'accordion',
								'class'      => 'pdt-pro-only',
								'accordions' => array(
									array(
										'title'  => esc_html__( 'Social Share', 'productify-pro' ),
										'fields' => array(
											array(
												'id'       => 'social_sharing_media',
												'type'     => 'select',
												'title'    => esc_html__( 'Sharing Media', 'productify-pro' ),
												'chosen'   => true,
												'sortable' => true,
												'multiple' => true,
												'placeholder' => esc_html__( 'Choose an option', 'productify-pro' ),
												'options'  => array(
													'facebook' => esc_html__( 'Facebook', 'productify-pro' ),
													'twitter' => esc_html__( 'Twitter', 'productify-pro' ),
													'linkedIn' => esc_html__( 'LinkedIn', 'productify-pro' ),
													'pinterest' => esc_html__( 'Pinterest', 'productify-pro' ),
													'email' => esc_html__( 'Email', 'productify-pro' ),
													'instagram' => esc_html__( 'Instagram', 'productify-pro' ),
													'vk'   => esc_html__( 'VK', 'productify-pro' ),
													'digg' => esc_html__( 'digg', 'productify-pro' ),
													'tumblr' => esc_html__( 'Tumblr', 'productify-pro' ),
													'reddit' => esc_html__( 'Reddit', 'productify-pro' ),
													'whatsapp' => esc_html__( 'WhatsApp', 'productify-pro' ),
													'pocket' => esc_html__( 'Pocket', 'productify-pro' ),
													'xing' => esc_html__( 'Xing', 'productify-pro' ),
												),
											),
											array(
												'id'      => 'social_position',
												'type'    => 'button_set',
												'title'   => esc_html__( 'Alignment', 'productify-pro' ),
												'options' => array(
													'left' => wp_kses( __( '<i class="fas fa-align-left" title="Left"></i>', 'productify-pro' ), array( 'i' => array( 'class' => array() ) ) ),
													'center' => wp_kses( __( '<i class="fas fa-align-center" title="Center"></i>', 'productify-pro' ), array( 'i' => array( 'class' => array() ) ) ),
													'right' => wp_kses( __( '<i class="fas fa-align-right" title="Right"></i>', 'productify-pro' ), array( 'i' => array( 'class' => array() ) ) ),
												),
												'default' => 'left',
												'dependency' => array( 'social_sharing_media', '!=', '' ),
											),
											array(
												'id'       => 'social_margin',
												'type'     => 'spacing',
												'title'    => esc_html__( 'Margin', 'productify-pro' ),
												'sanitize' => 'pdt_sanitize_number_array_field',
												'min'      => -100,
												'units'    => array( 'px' ),
												'default'  => array(
													'top'  => '0',
													'right' => '0',
													'bottom' => '0',
													'left' => '0',
												),
												'dependency' => array( 'social_sharing_media', '!=', '' ),
											),
											array(
												'id'      => 'social_icon_shape',
												'class'   => 'social_icon_shape',
												'type'    => 'layout_preset',
												'title'   => esc_html__( 'Icon Shape', 'productify-pro' ),
												'options' => array(
													'pdt_circle'    => array(
														'image'       => PDT_URL . 'admin/assets/img/circle-icon.png',
														'text' => esc_html__( 'Circle', 'productify-pro' ),
													),
													'pdt_rounded'   => array(
														'image'       => PDT_URL . 'admin/assets/img/round-icon.png',
														'text' => esc_html__( 'Rounded', 'productify-pro' ),
													),
													'pdt_square'    => array(
														'image'       => PDT_URL . 'admin/assets/img/square-icon.png',
														'text' => esc_html__( 'Square', 'productify-pro' ),
													),
													'icon_only' => array(
														'image'       => PDT_URL . 'admin/assets/img/only-icon.png',
														'text' => esc_html__( 'Icon only', 'productify-pro' ),
													),
												),
												'default' => 'pdt_circle',
												'dependency' => array( 'social_sharing_media', '!=', '' ),
											),
											array(
												'id'      => 'social_icon_custom_color',
												'type'    => 'checkbox',
												'title'   => esc_html__( 'Custom Color', 'productify-pro' ),
												'default' => false,
												'dependency' => array( 'social_sharing_media', '!=', '' ),
											),
											array(
												'id'      => 'social_icon_color',
												'type'    => 'color_group',
												'title'   => esc_html__( 'Icon Color', 'productify-pro' ),
												'options' => array(
													'icon_color'       => esc_html__( 'Icon', 'productify-pro' ),
													'icon_hover_color' => esc_html__( 'Icon Hover', 'productify-pro' ),
													'icon_bg'       => esc_html__( 'Background', 'productify-pro' ),
													'icon_bg_hover' => esc_html__( 'Background Hover', 'productify-pro' ),
													'icon_border_hover' => esc_html__( 'Border Hover', 'productify-pro' ),
												),
												'default' => array(
													'icon_color'       => '#ffffff',
													'icon_hover_color' => '#ffffff',
													'icon_bg'       => '#934899',
													'icon_bg_hover' => '#bf21cc',
													'icon_border_hover' => '#bf21cc',
												),
												'dependency' => array( 'social_icon_custom_color|social_sharing_media', '==|!=', 'true|' ),
											),
											array(
												'id'      => 'social_icon_border',
												'type'    => 'border',
												'title'   => esc_html__( 'Icon Border', 'productify-pro' ),
												'default' => array(
													'all' => '1',
													'style' => 'solid',
													'color' => '#934899',
												),
												'all'     => true,
												'dependency' => array( 'social_icon_custom_color|social_sharing_media', '==|!=', 'true|' ),
											),
										),
									),
								),
							), // PDT Post Social.
							array(
								'id'         => 'pdt_custom_fields',
								'type'       => 'accordion',
								'accordions' => array(
									array(
										'title'  => esc_html__( 'Custom Fields', 'productify-pro' ),
										'fields' => array(
											// The Group Fields.
											array(
												'id'     => 'pdt_custom_fields_group',
												'class'  => 'pdt_custom_group_design',
												'type'   => 'group',
												'accordion_title_auto' => true,
												'accordion_title_number' => true,
												'button_title' => esc_html__( 'Add New Custom Field', 'productify-pro' ),
												'fields' => array(
													array(
														'id'   => 'pdt_select_custom_field_key',
														'type' => 'select',
														'title' => esc_html__( 'Custom Fields', 'productify-pro' ),
														'options' => 'custom_fields',
														'chosen' => true,
														'attributes' => array(
															'style' => 'width: 200px;',
														),
														'empty_message' => esc_html__( 'No custom field found.', 'productify-pro' ),
													),
													array(
														'id'   => 'pdt_custom_meta_icon',
														'type' => 'icon',
														'title' => esc_html__( 'Icon Before Name', 'productify-pro' ),
														'default' => 'fas fa-calendar-alt',
													),
													array(
														'id'   => 'show_custom_field_name',
														'type' => 'switcher',
														'title'    => esc_html__( 'Custom Field Name', 'productify-pro' ),
														'text_on' => esc_html__( 'Show', 'productify-pro' ),
														'text_off' => esc_html__( 'Hide', 'productify-pro' ),
														'default' => false,
														'text_width' => 80,
													),
													array(
														'id'   => 'customize_custom_field_name',
														'type' => 'text',
														'title' => esc_html__( 'Customize Field Name', 'productify-pro' ),
														'dependency' => array( 'show_custom_field_name', '==', 'true' ),
													),
													array(
														'id'   => 'colon_after_custom_field_name',
														'type' => 'switcher',
														'title' => esc_html__( 'Show Colon \':\'', 'productify-pro' ),
														'title_help' => esc_html__( 'Show colon after field name.', 'productify-pro' ),
														'text_on' => esc_html__( 'Show', 'productify-pro' ),
														'text_off' => esc_html__( 'Hide', 'productify-pro' ),
														'default' => true,
														'text_width' => 80,
														'default' => false,
														'dependency' => array( 'show_custom_field_name', '==', 'true' ),
													),
												),
											), // Group field end.
											array(
												'id'      => 'which_plugin_used',
												'type'    => 'button_set',
												'title'   => esc_html__( 'Select Plugin', 'productify-pro' ),
												'title_help' => esc_html__( 'Select plugin which is used to make the above custom fields.', 'productify-pro' ),
												'options' => array(
													'auto' => esc_html__( 'Auto Detect', 'productify-pro' ),
													'_acf' => esc_html__( 'Advanced Custom Fields', 'productify-pro' ),
													'_pods' => esc_html__( 'Pods', 'productify-pro' ),
													'_toolset' => esc_html__( 'Toolset', 'productify-pro' ),
												),
												'default' => 'auto',
											),
											array(
												'id'    => 'pdt_embed_cf_content',
												'type'  => 'checkbox',
												'title' => esc_html__( 'Embed Audio, Video or Image etc.', 'productify-pro' ),
												'desc'  => __( 'Embed the content if it is audio, video, or tweets etc. <a target="_blank" href="https://wordpress.org/support/article/embeds/#okay-so-what-sites-can-i-embed-from">See embed supported content list.</a>', 'productify-pro' ),
											),
											array(
												'id'       => 'pdt_custom_fields_margin',
												'type'     => 'spacing',
												'title'    => esc_html__( 'Margin', 'productify-pro' ),
												'sanitize' => 'pdt_sanitize_number_array_field',
												'min'      => -100,
												'units'    => array( 'px' ),
												'default'  => array(
													'top'  => '0',
													'right' => '0',
													'bottom' => '15',
													'left' => '0',
												),
											),
										), // End Fields array.
									),
								), // Accordion.
							), // Custom fields end.
						),
					),
					array(
						'id'         => 'show_post_pagination',
						'type'       => 'switcher',
						'text_on'    => esc_html__( 'Enabled', 'productify-pro' ),
						'text_off'   => esc_html__( 'Disabled', 'productify-pro' ),
						'text_width' => 100,
						'title'      => esc_html__( 'Pagination', 'productify-pro' ),
						'subtitle'   => esc_html__( 'Enabled/Disabled item pagination.', 'productify-pro' ),
						'default'    => true,
						'dependency' => array( 'pdt_layout_preset', '!=', 'carousel_layout', true ),
					),
					array(
						'id'         => 'post_pagination_type',
						'type'       => 'radio',
						'title'      => esc_html__( 'Pagination Type', 'productify-pro' ),
						'subtitle'   => esc_html__( 'Choose a pagination type.', 'productify-pro' ),
						'options'    => array(
							'ajax_load_more'  => esc_html__( 'Load More Button (Ajax)', 'productify-pro' ),
							'ajax_pagination' => esc_html__( 'Ajax Number Pagination', 'productify-pro' ),
							'infinite_scroll' => esc_html__( 'Infinite Scroll (Ajax)', 'productify-pro' ),
							'no_ajax'         => esc_html__( 'No Ajax (Normal Pagination)', 'productify-pro' ),
						),
						'default'    => 'ajax_load_more',
						'dependency' => array( 'pdt_layout_preset|show_post_pagination', 'not-any|==', 'carousel_layout,filter_layout|true', true ),
					),
					array(
						'id'         => 'filter_pagination_type',
						'type'       => 'radio',
						'title'      => esc_html__( 'Filter Pagination Type', 'productify-pro' ),
						'subtitle'   => esc_html__( 'Choose a pagination type.', 'productify-pro' ),
						'options'    => array(
							'ajax_load_more'  => esc_html__( 'Load More Button (Ajax)', 'productify-pro' ),
							'infinite_scroll' => esc_html__( 'Infinite Scroll (Ajax)', 'productify-pro' ),
						),
						'default'    => 'ajax_load_more',
						'dependency' => array( 'pdt_layout_preset|show_post_pagination', '==|==', 'filter_layout|true', true ),
					),
					array(
						'id'         => 'post_pagination_type_mobile',
						'type'       => 'select',
						'title'      => esc_html__( 'Pagination Type for Mobile', 'productify-pro' ),
						'subtitle'   => esc_html__( 'Choose a pagination type for mobile view.', 'productify-pro' ),
						'options'    => array(
							'ajax_load_more'  => esc_html__( 'Load More Button (Ajax)', 'productify-pro' ),
							'ajax_pagination' => esc_html__( 'Ajax Pagination', 'productify-pro' ),
							'infinite_scroll' => esc_html__( 'Infinite Scroll (Ajax)', 'productify-pro' ),
							'no_ajax'         => esc_html__( 'No Ajax (Normal Pagination)', 'productify-pro' ),
						),
						'default'    => 'infinite_scroll',
						'dependency' => array( 'pdt_layout_preset|show_post_pagination', 'not-any|==', 'carousel_layout,filter_layout|true', true ),
					),
					array(
						'id'         => 'load_more_button_text',
						'type'       => 'text',
						'title'      => esc_html__( 'Load More Button Label', 'productify-pro' ),
						'subtitle'   => esc_html__( 'Set the label for load more button.', 'productify-pro' ),
						'default'    => esc_html__( 'Load More', 'productify-pro' ),
						'dependency' => array( 'pdt_layout_preset|show_post_pagination', '!=|==', 'carousel_layout|true', true ),
					),
					array(
						'id'         => 'load_more_ending_message',
						'type'       => 'text',
						'title'      => esc_html__( 'Ending Message', 'productify-pro' ),
						'subtitle'   => esc_html__( 'Set ending message for load more/infinite scroll.', 'productify-pro' ),
						'default'    => esc_html__( 'No more products available', 'productify-pro' ),
						'dependency' => array( 'pdt_layout_preset|show_post_pagination', '!=|==', 'carousel_layout|true', true ),
					),
					array(
						'id'         => 'pdt_pagination_btn_color',
						'type'       => 'color_group',
						'title'      => esc_html__( 'Pagination  Color', 'productify-pro' ),
						'subtitle'   => esc_html__( 'Set Pagination color', 'productify-pro' ),
						'options'    => array(
							'text_color'        => esc_html__( 'Text Color', 'productify-pro' ),
							'text_acolor'       => esc_html__( 'Text Active Color', 'productify-pro' ),
							'border_color'      => esc_html__( 'Border Color', 'productify-pro' ),
							'border_acolor'     => esc_html__( 'Border Active Color', 'productify-pro' ),
							'background'        => esc_html__( 'Background', 'productify-pro' ),
							'active_background' => esc_html__( 'Active BG', 'productify-pro' ),
						),
						'default'    => array(
							'text_color'        => '#5e5e5e',
							'text_acolor'       => '#ffffff',
							'border_color'      => '#bbbbbb',
							'border_acolor'     => '#934899',
							'background'        => '#ffffff',
							'active_background' => '#934899',
						),
						'dependency' => array( 'pdt_layout_preset|show_post_pagination|post_pagination_type', '!=|==|any', 'carousel_layout|true|ajax_pagination,no_ajax', true ),
					),
					array(
						'id'         => 'pdt_pagination_btn_border_radius',
						'type'       => 'spacing',
						'title'      => esc_html__( 'Pagination Border Radius', 'productify-pro' ),
						'subtitle'   => esc_html__( 'Set pagination border radius for item.', 'productify-pro' ),
						'all'        => true,
						'units'      => array( 'px', '%' ),
						'default'    => array(
							'all' => '0',
						),
						'dependency' => array( 'pdt_layout_preset|show_post_pagination|post_pagination_type', '!=|==|any', 'carousel_layout|true|ajax_pagination,no_ajax', true ),
					),
					array(
						'id'         => 'pdt_pagination_btn_margin_between',
						'type'       => 'spacing',
						'title'      => esc_html__( 'Pagination Margin Between', 'productify-pro' ),
						'subtitle'   => esc_html__( 'Set pagination border radius for item.', 'productify-pro' ),
						'all'        => true,
						'units'      => array( 'px' ),
						'default'    => array(
							'all' => '0',
						),
						'dependency' => array( 'pdt_layout_preset|show_post_pagination|post_pagination_type', '!=|==|any', 'carousel_layout|true|ajax_pagination,no_ajax', true ),
					),
					array(
						'id'         => 'pdt_loadmore_btn_color',
						'type'       => 'color_group',
						'title'      => esc_html__( 'Load More Button Color', 'productify-pro' ),
						'subtitle'   => esc_html__( 'Set load more button color.', 'productify-pro' ),
						'options'    => array(
							'text_color'        => esc_html__( 'Text Color', 'productify-pro' ),
							'text_hcolor'       => esc_html__( 'Text hover Color', 'productify-pro' ),
							'background'        => esc_html__( 'Background', 'productify-pro' ),
							'active_background' => esc_html__( 'Hover Background', 'productify-pro' ),
						),
						'default'    => array(
							'text_color'        => '#ffffff',
							'text_hcolor'       => '#5e5e5e',
							'background'        => '#934899',
							'active_background' => '#ffffff',
						),
						'dependency' => array( 'pdt_layout_preset|show_post_pagination|post_pagination_type', '!=|==|==', 'carousel_layout|true|ajax_load_more', true ),
					),
					array(
						'id'         => 'pagination_alignment',
						'type'       => 'button_set',
						'title'      => esc_html__( 'Alignment', 'productify-pro' ),
						'subtitle'   => esc_html__( 'Choose pagination alignment.', 'productify-pro' ),
						'options'    => array(
							'left'   => wp_kses( __( '<i class="fas fa-align-left" title="Left"></i>', 'productify-pro' ), array( 'i' => array( 'class' => array() ) ) ),
							'center' => wp_kses( __( '<i class="fas fa-align-center" title="Center"></i>', 'productify-pro' ), array( 'i' => array( 'class' => array() ) ) ),
							'right'  => wp_kses( __( '<i class="fas fa-align-right" title="Right"></i>', 'productify-pro' ), array( 'i' => array( 'class' => array() ) ) ),
						),
						'default'    => 'left',
						'dependency' => array( 'pdt_layout_preset|show_post_pagination', '!=|==', 'carousel_layout|true', true ),
					),
					array(
						'id'         => 'post_per_page',
						'type'       => 'spinner',
						'title'      => esc_html__( 'Items Per Page', 'productify-pro' ),
						'subtitle'   => esc_html__( 'Set number of items to show per page.', 'productify-pro' ),
						'title_help' => esc_html__( 'This value should be lesser than that <strong> Limit </strong> from <strong>Filter Content  </strong> tab.', 'productify-pro' ),
						'sanitize'   => 'pdt_sanitize_number_field',
						'default'    => 12,
						'dependency' => array( 'pdt_layout_preset|show_post_pagination', '!=|==', 'carousel_layout|true', true ),
					),
					array(
						'id'         => 'show_preloader',
						'type'       => 'switcher',
						'title'      => esc_html__( 'Preloader', 'productify-pro' ),
						'subtitle'   => esc_html__( 'Items will be hidden until page load completed.', 'productify-pro' ),
						'text_on'    => esc_html__( 'Enabled', 'productify-pro' ),
						'text_off'   => esc_html__( 'Disabled', 'productify-pro' ),
						'text_width' => 100,
						'default'    => false,
					),
					array(
						'type'    => 'subheading',
						'class'   => 'pdt_filter_btn_color hidden',
						'content' => esc_html__( 'Live Filter Button', 'productify-pro' ),
					),
				), // End of fields array.
			)
		); // Display settings section end.
	}
}
