<?php
/**
 * The Filter Post Meta-box configurations.
 *
 * @package Productify_pro
 * @subpackage admin
 */

if ( ! defined( 'ABSPATH' ) ) {
	die; } // Cannot access pages directly.

/**
 * The Filter post building class.
 */
class PDT_FilterPost {

	/**
	 * Filter Post section metabox.
	 *
	 * @param string $prefix The metabox key.
	 * @return void
	 */
	public static function section( $prefix ) {
		PDT::createSection(
			$prefix,
			array(
				'title'  => esc_html__( 'Filter Content', 'productify-pro' ),
				'icon'   => 'fas fa-filter',
				'fields' => array(

					array(
						'id'          => 'pdt_include_only_posts',
						'type'        => 'select',
						'title'       => esc_html__( 'Include Only', 'productify-pro' ),
						'subtitle'    => esc_html__( 'Choose posts to include by title.', 'productify-pro' ),
						'options'     => 'posts',
						'ajax'        => true,
						'sortable'    => true,
						'chosen'      => true,
						'class'       => 'ta_pdt_include_only_posts',
						'multiple'    => true,
						'placeholder' => esc_html__( 'Choose posts', 'productify-pro' ),
						'query_args'  => array(
							'post_type'     => 'product',
							'cache_results' => false,
							'no_found_rows' => true,
						),
					),
					array(
						'id'       => 'pdt_exclude_post_set',
						'type'     => 'fieldset',
						'title'    => esc_html__( 'Exclude', 'productify-pro' ),
						'subtitle' => esc_html__( 'Choose posts to exclude by title.', 'productify-pro' ),
						'class'    => 'ta_pdt_exclude_post_set',
						'fields'   => array(
							array(
								'id'          => 'pdt_exclude_posts',
								'type'        => 'select',
								'options'     => 'posts',
								'chosen'      => true,
								'class'       => 'ta_pdt_exclude_posts',
								'multiple'    => true,
								'ajax'        => true,
								'placeholder' => esc_html__( 'Choose posts to exclude', 'productify-pro' ),
								'query_args'  => array(
									'post_type'     => 'product',
									'cache_results' => false,
									'no_found_rows' => true,
								),
								'dependency'  => array( 'pdt_include_only_posts', '==', '', true ),
							),
							array(
								'id'      => 'pdt_exclude_too',
								'type'    => 'checkbox',
								'class'   => 'ta_pdt_exclude_too',
								'options' => array(
									'current'            => esc_html__( 'Current Post', 'productify-pro' ),
									'password_protected' => esc_html__( 'Password Protected Posts', 'productify-pro' ),
									'children'           => esc_html__( 'Children Posts', 'productify-pro' ),
								),
							),
						),
					),
					array(
						'id'         => 'product_type',
						'type'       => 'select',
						'title'      => esc_html__( 'Product Type', 'productify-pro' ),
						'subtitle'   => esc_html__( 'Filter the products you want to show.', 'productify-pro' ),
						'options'    => array(
							'latest_products'   => esc_html__( 'Latest', 'productify-pro' ),
							'featured_products' => esc_html__( 'Featured', 'productify-pro' ),
						),
						'attributes' => array(
							'style' => 'width: 200px;',
						),
						'default'    => 'latest',
					),
					array(
						'id'       => 'hide_out_of_stock_product',
						'type'     => 'checkbox',
						'title'    => esc_html__( 'Hide Out of Stock Products', 'productify-pro' ),
						'subtitle' => esc_html__( 'Check to hide out of stock products.', 'productify-pro' ),
						'default'  => false,
					),
					array(
						'id'       => 'pdt_product_limit',
						'title'    => esc_html__( 'Limit', 'productify-pro' ),
						'type'     => 'spinner',
						'subtitle' => esc_html__( 'Number of total items to display. Leave it empty to show all found items.', 'productify-pro' ),
						'sanitize' => 'pdt_sanitize_number_field',
						'default'  => '15',
						'min'      => 1,
					),
					array(
						'id'       => 'pdt_product_offset',
						'type'     => 'spinner',
						'title'    => esc_html__( 'Offset', 'productify-pro' ),
						'subtitle' => esc_html__( 'Number of items to skip.', 'productify-pro' ),
						'sanitize' => 'pdt_sanitize_number_field',
						'default'  => 0,
					),
					array(
						'type'    => 'subheading',
						'content' => esc_html__( 'Advanced Filtering', 'productify-pro' ),
					),
					array(
						'id'       => 'pdt_advanced_filter',
						'type'     => 'checkbox',
						'class'    => 'pdt_column_1 pdt_advanced_filter',
						'title'    => esc_html__( 'Filter by', 'productify-pro' ),
						'subtitle' => esc_html__( 'Check the option(s) to filter by.', 'productify-pro' ),
						'options'  => array(
							'taxonomy' => esc_html__( 'Taxonomy', 'productify-pro' ),
							'sortby'   => esc_html__( 'Sort By', 'productify-pro' ),
						),
					),
					array(
						'id'         => 'pdt_filter_by_taxonomy',
						'type'       => 'accordion',
						'class'      => 'padding-t-0 pdt-opened-accordion',
						'accordions' => array(
							array(
								'title'  => esc_html__( 'Taxonomy', 'productify-pro' ),
								'icon'   => 'fas fa-folder-open',
								'fields' => array(
									// The Group Fields.
									array(
										'id'     => 'pdt_taxonomy_and_terms',
										'type'   => 'group',
										'class'  => 'pdt_taxonomy_terms_group pdt_custom_group_design',
										'accordion_title_auto' => true,
										'fields' => array(
											array(
												'id'      => 'pdt_select_taxonomy',
												'type'    => 'select',
												'title'   => esc_html__( 'Select Taxonomy', 'productify-pro' ),
												'class'   => 'ta_pdt_product_taxonomy',
												'options' => 'taxonomy',
												'query_args' => array(
													'type' => 'post',
												),
												'attributes' => array(
													'style' => 'width: 200px;',
												),
												'empty_message' => esc_html__( 'No taxonomies found.', 'productify-pro' ),
											),
											array(
												'id'      => 'hide_taxonomy_name',
												'type'    => 'checkbox',
												'title'   => esc_html__( 'Hide Taxonomy Name', 'productify-pro' ),
												'class'   => 'hide_taxonomy_name',
												'default' => false,
											),
											array(
												'id'       => 'pdt_select_terms',
												'type'     => 'select',
												'title'    => esc_html__( 'Choose Term(s)', 'productify-pro' ),
												'title_help' => esc_html__( 'Choose the taxonomy term(s) to show the posts from. Leave empty to show all found taxonomy term(s).', 'productify-pro' ),
												'options'  => 'terms',
												'class'    => 'ta_pdt_taxonomy_terms',
												'width'    => '300px',
												'multiple' => true,
												'sortable' => true,
												'empty_message' => esc_html__( 'No terms found.', 'productify-pro' ),
												'placeholder' => esc_html__( 'Select Term(s)', 'productify-pro' ),
												'chosen'   => true,
											),
											array(
												'id'      => 'pdt_taxonomy_term_operator',
												'type'    => 'select',
												'title'   => esc_html__( 'Operator', 'productify-pro' ),
												'options' => array(
													'IN'  => esc_html__( 'IN', 'productify-pro' ),
													'AND' => esc_html__( 'AND', 'productify-pro' ),
													'NOT IN' => esc_html__( 'NOT IN', 'productify-pro' ),
												),
												'default' => 'IN',
												'title_help' => esc_html__( 'IN - Show posts which associate with one or more terms<br>AND - Show posts which match all terms<br>NOT IN - Show posts which don\'t match the terms', 'productify-pro' ),
											),
											array(
												'id'    => 'add_filter_post',
												'type'  => 'checkbox',
												'title' => esc_html__( 'Add to Ajax Live Filters', 'productify-pro' ),
												'title_help' => esc_html__( 'Check to add ajax live filters.', 'productify-pro' ),
											),
											array(
												'id'     => 'ajax_filter_options',
												'type'   => 'fieldset',
												'title'  => esc_html__( 'Ajax Live Filters', 'productify-pro' ),
												'dependency' => array( 'add_filter_post', '==', 'true' ),
												'fields' => array(
													array(
														'id'       => 'ajax_filter_style',
														'type'     => 'select',
														'title'    => esc_html__( 'Filter Type', 'productify-pro' ),
														'title_help' => esc_html__( 'Select a type for live filter.', 'productify-pro' ),
														'options'  => array(
															'fl_dropdown' => esc_html__( 'Dropdown', 'productify-pro' ),
															'fl_radio'    => esc_html__( 'Radio', 'productify-pro' ),
															'fl_checkbox'      => esc_html__( 'Checkbox', 'productify-pro' ),
															'fl_btn'      => esc_html__( 'Button', 'productify-pro' ),
														),
														'default'  => 'fl_btn',
													),
													array(
														'id'       => 'pdt_filter_btn_color',
														'type'     => 'color_group',
														'title'    => esc_html__( 'Button Color', 'productify-pro' ),
														'dependency' => array( 'ajax_filter_style', '==', 'fl_btn' ),
														'options'  => array(
															'text_color'        => esc_html__( 'Text Color', 'productify-pro' ),
															'text_acolor'       => esc_html__( 'Text Hover', 'productify-pro' ),
															'border_color'      => esc_html__( 'Border Color', 'productify-pro' ),
															'border_acolor'     => esc_html__( 'Border Hover', 'productify-pro' ),
															'background'        => esc_html__( 'Background', 'productify-pro' ),
															'active_background' => esc_html__( 'Active/Hover BG', 'productify-pro' ),
														),
														'default'  => array(
															'text_color'        => '#5e5e5e',
															'text_acolor'       => '#ffffff',
															'border_color'      => '#bbbbbb',
															'border_acolor'     => '#934899',
															'background'        => '#ffffff',
															'active_background' => '#934899',
														),
													),
													array(
														'id'         => 'pdt_margin_between_button',
														'type'       => 'spacing',
														'title'      => esc_html__( 'Margin Between Buttons', 'productify-pro' ),
														'sanitize'   => 'pdt_sanitize_number_array_field',
														'subtitle'   => esc_html__( 'Set margin between buttons.', 'productify-pro' ),
														'units'      => array( 'px' ),
														'default'    => array(
															'top'    => '0',
															'right'  => '8',
															'bottom' => '8',
															'left'   => '0',
															'unit'   => 'px',
														),
														'dependency' => array( 'ajax_filter_style', '==', 'fl_btn' ),
													),
													array(
														'id'       => 'ajax_filter_label',
														'type'     => 'text',
														'title'    => esc_html__( 'Label', 'productify-pro' ),
														'title_help' => esc_html__( 'Type live filter label.', 'productify-pro' ),
													),
													array(
														'id'       => 'ajax_rename_all_text',
														'type'     => 'text',
														'title'    => esc_html__( 'Rename "All" Text', 'productify-pro' ),
														'title_help' => esc_html__( 'Leave it empty to hide "All" text.', 'productify-pro' ),
														'default'  => esc_html__( 'All', 'productify-pro' ),
														'dependency' => array( 'ajax_filter_style', '!=', 'fl_checkbox' ),
													),
													array(
														'id'       => 'ajax_hide_empty',
														'type'     => 'checkbox',
														'title'    => esc_html__( 'Hide Empty Term(s)', 'productify-pro' ),
														'title_help' => esc_html__( 'Check to hide empty terms.', 'productify-pro' ),
													),
													array(
														'id'       => 'ajax_show_count',
														'type'     => 'checkbox',
														'title'    => esc_html__( 'Show Post Count', 'productify-pro' ),
														'title_help' => esc_html__( 'Check to show post count.', 'productify-pro' ),
														'default'  => false,
													),
													array(
														'id'       => 'pdt_live_filter_align',
														'type'     => 'button_set',
														'title'    => esc_html__( 'Alignment', 'productify-pro' ),
														'options'    => array(
															'left'   => wp_kses( __( '<i class="fas fa-align-left" title="Left"></i>', 'productify-pro' ), array( 'i' => array( 'class' => array() ) ) ),
															'center' => wp_kses( __( '<i class="fas fa-align-center" title="Center"></i>', 'productify-pro' ), array( 'i' => array( 'class' => array() ) ) ),
															'right'  => wp_kses( __( '<i class="fas fa-align-right" title="Right"></i>', 'productify-pro' ), array( 'i' => array( 'class' => array() ) ) ),
														),
														'default'  => 'center',
													),
												),
											),

										),
									), // Group field end.
									array(
										'id'         => 'pdt_taxonomies_relation',
										'type'       => 'select',
										'title'      => esc_html__( 'Relation', 'productify-pro' ),
										'class'      => 'pdt_relate_among_taxonomies',
										'options'    => array(
											'AND' => esc_html__( 'AND', 'productify-pro' ),
											'OR'  => esc_html__( 'OR', 'productify-pro' ),
										),
										'default'    => 'AND',
										'title_help' => esc_html__( 'The logical relationship between/among above taxonomies.', 'productify-pro' ),
									),

								), // Fields array.
							),
						), // Accordions end.
						'dependency' => array( 'pdt_advanced_filter', 'not-any', 'sortby' ),
					),

					array(
						'id'         => 'pdt_filter_by_order',
						'type'       => 'accordion',
						'class'      => 'padding-t-0 pdt-opened-accordion',
						'accordions' => array(
							array(
								'title'  => esc_html__( 'Sort By', 'productify-pro' ),
								'icon'   => 'fas fa-sort',
								'fields' => array(
									array(
										'id'      => 'pdt_select_filter_orderby',
										'type'    => 'select',
										'title'   => esc_html__( 'Order by', 'productify-pro' ),
										'options' => array(
											'ID'         => esc_html__( 'ID', 'productify-pro' ),
											'title'      => esc_html__( 'Title', 'productify-pro' ),
											'date'       => esc_html__( 'Date', 'productify-pro' ),
											'modified'   => esc_html__( 'Modified date', 'productify-pro' ),
											'post_slug'  => esc_html__( 'Post slug', 'productify-pro' ),
											'post_type'  => esc_html__( 'Post type', 'productify-pro' ),
											'rand'       => esc_html__( 'Random', 'productify-pro' ),
											'comment_count' => esc_html__( 'Comment count', 'productify-pro' ),
											'menu_order' => esc_html__( 'Menu order', 'productify-pro' ),
											'most_liked' => esc_html__( 'Most Liked', 'productify-pro' ),
										),
										'default' => 'date',
									),
									array(
										'id'         => 'orderby_custom_field_options',
										'type'       => 'fieldset',
										'title'      => esc_html__( 'Order by Custom Field', 'productify-pro' ),
										'dependency' => array( 'pdt_select_filter_orderby', '==', 'custom_field', true ),
										'fields'     => array(
											array(
												'id'      => 'pdt_select_custom_field_key',
												'type'    => 'select',
												'title'   => esc_html__( 'Custom Fields Keys', 'productify-pro' ),
												'title_help' => esc_html__( 'Select custom fields key.', 'productify-pro' ),
												'options' => 'custom_fields',
												'chosen'  => true,
												'attributes' => array(
													'style' => 'width: 200px;',
												),
												'empty_message' => esc_html__( 'No custom field keys found.', 'productify-pro' ),
											),
											array(
												'id'      => 'pdt_select_custom_field_value_type',
												'type'    => 'select',
												'title'   => esc_html__( 'Value Type', 'productify-pro' ),
												'title_help' => esc_html__( 'Select a value type.', 'productify-pro' ),
												'options' => array(
													'CHAR' => esc_html__( 'Text', 'productify-pro' ),
													'NUMERIC' => esc_html__( 'Number', 'productify-pro' ),
													'DATE' => esc_html__( 'Date', 'productify-pro' ),
													'BOOLEAN' => esc_html__( 'True/False', 'productify-pro' ),
												),
												'default' => 'NUMERIC',
											),
										),
									),
									array(
										'id'         => 'pdt_select_filter_order',
										'type'       => 'select',
										'title'      => esc_html__( 'Order', 'productify-pro' ),
										'options'    => array(
											'ASC'  => esc_html__( 'Ascending', 'productify-pro' ),
											'DESC' => esc_html__( 'Descending', 'productify-pro' ),
										),
										'default'    => 'DESC',
										'dependency' => array( 'pdt_select_filter_orderby', '!=', 'post__in' ),
									),
									array(
										'id'         => 'add_order_filter_post',
										'type'       => 'checkbox',
										'title'      => esc_html__( 'Add to Ajax Live Filters', 'productify-pro' ),
										'title_help' => esc_html__( 'Check to add ajax live filter for order.', 'productify-pro' ),
										'dependency' => array( 'pdt_select_filter_orderby|pdt_layout_preset', '!=|!=', 'post__in|filter_layout', true ),
									),
									array(
										'id'         => 'order_filter_options',
										'type'       => 'fieldset',
										'title'      => esc_html__( 'Ajax Live Filters', 'productify-pro' ),
										'dependency' => array( 'add_order_filter_post|pdt_select_filter_orderby', '==|!=', 'true|post__in', true ),
										'fields'     => array(
											array(
												'id'      => 'order_filter_style',
												'type'    => 'select',
												'title'   => esc_html__( 'Filter Type', 'productify-pro' ),
												'title_help' => esc_html__( 'Select a type for live filter.', 'productify-pro' ),
												'options' => array(
													'fl_dropdown' => esc_html__( 'Dropdown', 'productify-pro' ),
													'fl_radio'    => esc_html__( 'Radio', 'productify-pro' ),
													'fl_btn'      => esc_html__( 'Button', 'productify-pro' ),
												),
												'default' => 'fl_btn',
											),
											array(
												'id'      => 'pdt_order_filter_button_color',
												'type'    => 'color_group',
												'title'   => esc_html__( 'Button Color', 'productify-pro' ),
												'dependency' => array( 'order_filter_style', '==', 'fl_btn' ),
												'options' => array(
													'text_color'        => esc_html__( 'Text Color', 'productify-pro' ),
													'text_acolor'       => esc_html__( 'Text Hover', 'productify-pro' ),
													'border_color'      => esc_html__( 'Border Color', 'productify-pro' ),
													'border_acolor'     => esc_html__( 'Border Hover', 'productify-pro' ),
													'background'        => esc_html__( 'Background', 'productify-pro' ),
													'active_background' => esc_html__( 'Active/Hover BG', 'productify-pro' ),
												),
												'default' => array(
													'text_color'        => '#5e5e5e',
													'text_acolor'       => '#ffffff',
													'border_color'      => '#bbbbbb',
													'border_acolor'     => '#934899',
													'background'        => '#ffffff',
													'active_background' => '#934899',
												),
											),
											array(
												'id'      => 'order_filter_label',
												'type'    => 'text',
												'title'   => esc_html__( 'Label', 'productify-pro' ),
												'title_help' => esc_html__( 'Type live filter label.', 'productify-pro' ),
												'default' => esc_html__( 'Order', 'productify-pro' ),
											),
											array(
												'id'      => 'pdt_live_filter_align',
												'type'    => 'button_set',
												'title'   => esc_html__( 'Alignment', 'productify-pro' ),
												'options' => array(
													'left' => wp_kses( __( '<i class="fas fa-align-left" title="Left"></i>', 'productify-pro' ), array( 'i' => array( 'class' => array() ) ) ),
													'center' => wp_kses( __( '<i class="fas fa-align-center" title="Center"></i>', 'productify-pro' ), array( 'i' => array( 'class' => array() ) ) ),
													'right' => wp_kses( __( '<i class="fas fa-align-right" title="Right"></i>', 'productify-pro' ), array( 'i' => array( 'class' => array() ) ) ),
												),
												'default' => 'center',
											),

										),
									),
								),
							),
						),
						'dependency' => array( 'pdt_advanced_filter', 'not-any', 'taxonomy' ),
					),
				),
			)
		); // Filter settings section end.
	}
}
