<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://themeatelier.net
 * @since      1.0.0
 *
 * @package    Productify_Pro
 * @subpackage Productify_Pro/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Productify_Pro
 * @subpackage Productify_Pro/public
 * @author     ThemeAtelier <themeatelierbd@gmail.com>
 */
class Productify_Pro_Public {


	/**
	 * Script and style suffix
	 *
	 * @since 2.2.0
	 * @access protected
	 * @var string
	 */
	protected $suffix;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string $plugin_name       The name of the plugin.
	 * @param      string $version    The version of this plugin.
	 */
	public function __construct() {
		$this->load_public_dependencies();
		$this->pdt_public_action();
	}

	private function load_public_dependencies() {
		require_once PDT_PATH . 'public/helpers/class-post-functions.php';
		require_once PDT_PATH . 'public/helpers/class-pdt-user-like.php';
		new PDT_User_Like();
		require_once PDT_PATH . 'public/helpers/class-pdt-queryinside.php';
		require_once PDT_PATH . 'public/helpers/class-pdt-customfieldprocess.php';
		require_once PDT_PATH . 'public/helpers/class-pdt-shuffle-filter.php';
		require_once PDT_PATH . 'public/helpers/class-pdt-live-filter.php';
		new PDT_Live_Filter();
		require_once PDT_PATH . 'public/helpers/class-loop-html.php';
	}

	private function pdt_public_action() {

		add_action( 'wp_ajax_post_grid_ajax', array( $this, 'post_grid_ajax' ) );
		add_action( 'wp_ajax_nopriv_post_grid_ajax', array( $this, 'post_grid_ajax' ) );

		add_action( 'wp_ajax_pdt_product_pdtup', array( $this, 'pdt_product_pdtup' ) );
		add_action( 'wp_ajax_nopriv_pdt_product_pdtup', array( $this, 'pdt_product_pdtup' ) );

		add_action( 'wp_ajax_pdt_product_pdtup_next_prev', array( $this, 'pdt_product_pdtup_next_prev' ) );
		add_action( 'wp_ajax_nopriv_pdt_product_pdtup_next_prev', array( $this, 'pdt_product_pdtup_next_prev' ) );

		add_action( 'wp_ajax_post_pagination_bar', array( $this, 'post_pagination_bar' ) );
		add_action( 'wp_ajax_nopriv_post_pagination_bar', array( $this, 'post_pagination_bar' ) );

		add_action( 'wp_ajax_post_pagination_bar_mobile', array( $this, 'post_pagination_bar_mobile' ) );
		add_action( 'wp_ajax_nopriv_post_pagination_bar_mobile', array( $this, 'post_pagination_bar_mobile' ) );

		add_action( 'wp_ajax_pdt_product_order', array( $this, 'pdt_product_order' ) );
		add_action( 'wp_ajax_nopriv_pdt_product_order', array( $this, 'pdt_product_order' ) );

		add_shortcode( 'productify', array( $this, 'pdt_shortcode_render' ) );

		$this->suffix = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) || ( defined( 'WP_DEBUG' ) && WP_DEBUG ) ? '' : '.min';
	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Productify_Pro_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Productify_Pro_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		$pdt_settings        = get_option( 'ta_productify_settings' );
		$pdt_fontawesome_css = isset( $pdt_settings['pdt_fontawesome_css'] ) ? $pdt_settings['pdt_fontawesome_css'] : true;
		$pdt_swiper_css      = isset( $pdt_settings['pdt_swiper_css'] ) ? $pdt_settings['pdt_swiper_css'] : true;
		$pdt_bxslider_css    = isset( $pdt_settings['pdt_bxSlider_css'] ) ? $pdt_settings['pdt_bxSlider_css'] : true;
		$pdt_like_css        = isset( $pdt_settings['pdt_like_css'] ) ? $pdt_settings['pdt_like_css'] : true;
		$pdt_magnific_css    = isset( $pdt_settings['pdt_magnific_css'] ) ? $pdt_settings['pdt_magnific_css'] : true;
		if ( $pdt_fontawesome_css ) {
			wp_enqueue_style( 'fontawesome', PDT_URL . 'public/assets/css/fontawesome.min.css', array(), PDT_VERSION, 'all' );
		}
		if ( $pdt_swiper_css ) {
			wp_enqueue_style( 'swiperslider', PDT_URL . 'public/assets/css/swiper-bundle' . $this->suffix . '.css', array(), PDT_VERSION, 'all' );
		}
		if ( $pdt_bxslider_css ) {
			wp_enqueue_style( 'bxslider', PDT_URL . 'public/assets/css/jquery.bxslider' . $this->suffix . '.css', array(), PDT_VERSION, 'all' );
		}
		if ( $pdt_like_css ) {
			wp_enqueue_style( 'pdt-likes', PDT_URL . 'public/assets/css/pdt-likes-public' . $this->suffix . '.css', array(), PDT_VERSION, 'all' );
		}
		wp_enqueue_style( 'pdt-grid', PDT_URL . 'public/assets/css/ta-grid' . $this->suffix . '.css', array(), PDT_VERSION, 'all' );
		wp_enqueue_style( 'pdt-style', PDT_URL . 'public/assets/css/style' . $this->suffix . '.css', array(), PDT_VERSION, 'all' );

		$pdt_posts       = new WP_Query(
			array(
				'post_type'      => 'productify',
				'posts_per_page' => 900,
			)
		);
		$product_ids     = wp_list_pluck( $pdt_posts->posts, 'ID' );
		$custom_css      = '';
		$enqueue_fonts   = array();
		$setting_options = get_option( 'ta_productify_settings' );
		$pdt_custom_css  = isset( $setting_options['pdt_custom_css'] ) ? $setting_options['pdt_custom_css'] : '';

		$pdt_enqueue_google_font = isset( $setting_options['pdt_enqueue_google_font'] ) ? $setting_options['pdt_enqueue_google_font'] : true;
		foreach ( $product_ids as $pdt_id ) {
			// Include dynamic style file.
			$view_options = get_post_meta( $pdt_id, 'ta_pdt_view_options', true );
			$layouts      = get_post_meta( $pdt_id, 'ta_pdt_layouts', true );
			include 'dynamic-css/dynamic-css.php';

			if ( $pdt_enqueue_google_font ) {
				// Google fonts.
				$view_options     = get_post_meta( $pdt_id, 'ta_pdt_view_options', true );
				$all_fonts        = array();
				$pdt_typography   = array();
				$pdt_typography[] = $view_options['section_title_typography'];
				$pdt_typography[] = $view_options['post_title_typography'];
				$pdt_typography[] = $view_options['post_meta_typography'];
				$pdt_typography[] = $view_options['post_content_typography'];
				$pdt_typography[] = isset( $view_options['button_typography'] ) ? $view_options['button_typography'] : array(
					'font-family'        => '',
					'font-weight'        => '600',
					'subset'             => '',
					'font-size'          => '12',
					'tablet-font-size'   => '12',
					'mobile-font-size'   => '10',
					'line-height'        => '18',
					'tablet-line-height' => '18',
					'mobile-line-height' => '16',
					'letter-spacing'     => '0',
					'text-align'         => 'left',
					'text-transform'     => 'uppercase',
					'type'               => '',
					'unit'               => 'px',
				);
				if ( ! empty( $pdt_typography ) ) {
					foreach ( $pdt_typography as $font ) {
						if ( isset( $font['font-family'] ) && isset( $font['type'] ) && 'google' === $font['type'] ) {
							$variant     = ( isset( $font['font-weight'] ) && '' !== $font['font-weight'] ) ? ':' . $font['font-weight'] : '';
							$all_fonts[] = $font['font-family'] . $variant;
						}
					}
				}
				if ( $all_fonts ) {
					$enqueue_fonts[] = $all_fonts;
				}
			}
		}
		// Enqueue Google fonts.
		if ( $pdt_enqueue_google_font && ! empty( $enqueue_fonts ) ) {
			wp_enqueue_style( 'pdt-google-fonts', esc_url( add_query_arg( 'family', rawurlencode( implode( '|', array_merge( ...$enqueue_fonts ) ) ), '//fonts.googleapis.com/css' ) ), array(), PDT_VERSION, false );
		}
		include 'dynamic-css/responsive-css.php';
		if ( ! empty( $pdt_custom_css ) ) {
			$custom_css .= $pdt_custom_css;
		}
		// Add dynamic style.
		wp_add_inline_style( 'pdt-style', $custom_css );
	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Productify_Pro_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Productify_Pro_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_register_script( 'swiper', PDT_URL . 'public/assets/js/swiper-bundle' . $this->suffix . '.js', array( 'jquery' ), PDT_VERSION, true );
		wp_register_script( 'isotope', PDT_URL . 'public/assets/js/isotope' . $this->suffix . '.js', array( 'jquery' ), PDT_VERSION, true );
		wp_register_script( 'bxslider', PDT_URL . 'public/assets/js/jquery.bxslider' . $this->suffix . '.js', array( 'jquery' ), PDT_VERSION, true );
		wp_register_script( 'pdt-lazy', PDT_URL . 'public/assets/js/pdt-lazyload' . $this->suffix . '.js', array( 'jquery' ), PDT_VERSION, true );
		wp_register_script( 'pdt-script', PDT_URL . 'public/assets/js/scripts' . $this->suffix . '.js', array( 'swiper', 'bxslider' ), PDT_VERSION, true );
		wp_localize_script(
			'pdt-script',
			'sppdt',
			array(
				'ajaxurl' => admin_url( 'admin-ajax.php' ),
				'nonce'   => wp_create_nonce( 'sppdt_nonce' ),
			)
		);
	}

	public static function post_grid_ajax() {
		if ( isset( $_POST['nonce'] ) && ! wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['nonce'] ) ), 'sppdt_nonce' ) ) {
			return false;
		}
		$views_id            = isset( $_POST['id'] ) ? absint( $_POST['id'] ) : '';
		$keyword             = isset( $_POST['keyword'] ) ? sanitize_text_field( wp_unslash( $_POST['keyword'] ) ) : '';
		$orderby             = isset( $_POST['orderby'] ) ? sanitize_text_field( wp_unslash( $_POST['orderby'] ) ) : '';
		$order               = isset( $_POST['order'] ) ? sanitize_text_field( wp_unslash( $_POST['order'] ) ) : '';
		$taxonomy            = isset( $_POST['taxonomy'] ) ? sanitize_text_field( wp_unslash( $_POST['taxonomy'] ) ) : '';
		$term_id             = isset( $_POST['term_id'] ) ? sanitize_text_field( wp_unslash( $_POST['term_id'] ) ) : '';
		$pdt_lang            = isset( $_POST['lang'] ) ? sanitize_text_field( wp_unslash( $_POST['lang'] ) ) : '';
		$paged               = isset( $_POST['page'] ) ? sanitize_text_field( wp_unslash( $_POST['page'] ) ) : '';
		$custom_fields_array = isset( $_POST['custom_fields_array'] ) ? wp_unslash( $_POST['custom_fields_array'] ) : '';
		$selected_term_list  = isset( $_POST['term_list'] ) ? wp_unslash( $_POST['term_list'] ) : '';
		$layout              = get_post_meta( $views_id, 'ta_pdt_layouts', true );
		$layout_preset       = isset( $layout['pdt_layout_preset'] ) ? $layout['pdt_layout_preset'] : '';
		$view_options        = get_post_meta( $views_id, 'ta_pdt_view_options', true );
		// Post display settings.
		if ( 'filter_layout' === $layout_preset ) {
			$pagination_type        = isset( $view_options['filter_pagination_type'] ) ? $view_options['filter_pagination_type'] : '';
			$pagination_type_mobile = isset( $view_options['filter_pagination_type'] ) ? $view_options['filter_pagination_type'] : '';
		} else {
			$pagination_type        = isset( $view_options['post_pagination_type'] ) ? $view_options['post_pagination_type'] : '';
			$pagination_type_mobile = isset( $view_options['post_pagination_type_mobile'] ) ? $view_options['post_pagination_type_mobile'] : '';
		}

		if ( 'ajax_number' === $pagination_type ) {
			if ( empty( $paged ) ) {
				$paged = isset( $_POST['page'] ) ? sanitize_text_field( wp_unslash( $_POST['page'] ) ) : '';
			}
		}
		$product_content_sorter           = isset( $view_options['post_content_sorter'] ) ? $view_options['post_content_sorter'] : '';
		$query_args                       = PDT_QueryInside::get_filtered_content( $view_options, $views_id, $layout_preset );
		$product_limit                    = isset( $view_options['pdt_product_limit'] ) && ! empty( $view_options['pdt_product_limit'] ) ? $view_options['pdt_product_limit'] : 10000;
		$product_offset                   = isset( $view_options['pdt_product_offset'] ) ? $view_options['pdt_product_offset'] : 0;
		$new_query_args                   = $query_args;
		$new_query_args['fields']         = 'ids';
		$new_query_args['posts_per_page'] = $product_limit;
		$query_post_ids                   = get_posts( $new_query_args );
		$relation                         = isset( $view_options['pdt_filter_by_taxonomy']['pdt_taxonomies_relation'] ) ? $view_options['pdt_filter_by_taxonomy']['pdt_taxonomies_relation'] : 'AND';
		$query_args                       = PDT_Functions::modify_query_params( $query_args, $keyword, $custom_fields_array, $orderby, $order, $selected_term_list, $product_offset, $relation, $query_post_ids, $pdt_lang );
		$new_query_args                   = $query_args;
		$new_query_args['fields']         = 'ids';
		$new_query_args['posts_per_page'] = $product_limit;
		$total_posts                      = count( get_posts( $new_query_args ) );
		$product_limit                    = $total_posts;
		if ( $product_limit > 0 ) {
			$product_per_page = isset( $view_options['post_per_page'] ) ? $view_options['post_per_page'] : '';
			$product_per_page = ( $product_per_page > $product_limit ) ? $product_limit : $product_per_page;
			if ( $product_limit < 1 ) {
				$total_page = 0;
			} else {
				$total_page = PDT_Functions::pdt_max_pages( $product_limit, $product_per_page );
			}
			$pdt_last_page_post   = PDT_Functions::pdt_last_page_post( $product_limit, $product_per_page, $total_page );
			$offset               = (int) $product_per_page * ( $paged - 1 );
			$query_args['offset'] = (int) $offset + (int) $product_offset;
			if ( $total_page == $paged ) {
				$query_args['posts_per_page'] = $pdt_last_page_post;
			}
			if ( $paged > $total_page ) {
				return false;
			}
		}

		$query_args['paged'] = $paged;
		$pdt_query           = new WP_Query( $query_args );
		PDT_HTML::pdt_get_posts( $view_options, $layout_preset, $product_content_sorter, $pdt_query, $views_id );
		die();
	}

	/**
	 * Post Ajax Pagination.
	 */
	public static function post_pagination_bar() {
		if ( isset( $_POST['nonce'] ) && ! wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['nonce'] ) ), 'sppdt_nonce' ) ) {
			return false;
		}
		$views_id            = isset( $_POST['id'] ) ? absint( $_POST['id'] ) : '';
		$keyword             = isset( $_POST['keyword'] ) ? sanitize_text_field( wp_unslash( $_POST['keyword'] ) ) : '';
		$orderby             = isset( $_POST['orderby'] ) ? sanitize_text_field( wp_unslash( $_POST['orderby'] ) ) : '';
		$order               = isset( $_POST['order'] ) ? sanitize_text_field( wp_unslash( $_POST['order'] ) ) : '';
		$taxonomy            = isset( $_POST['taxonomy'] ) ? sanitize_text_field( wp_unslash( $_POST['taxonomy'] ) ) : '';
		$term_id             = isset( $_POST['term_id'] ) ? sanitize_text_field( wp_unslash( $_POST['term_id'] ) ) : '';
		$pdt_lang            = isset( $_POST['lang'] ) ? sanitize_text_field( wp_unslash( $_POST['lang'] ) ) : '';
		$paged               = isset( $_POST['page'] ) ? sanitize_text_field( wp_unslash( $_POST['page'] ) ) : '';
		$custom_fields_array = isset( $_POST['custom_fields_array'] ) ? wp_unslash( $_POST['custom_fields_array'] ) : '';
		$selected_term_list  = isset( $_POST['term_list'] ) ? wp_unslash( $_POST['term_list'] ) : '';
		$view_options        = get_post_meta( $views_id, 'ta_pdt_view_options', true );
		$layout              = get_post_meta( $views_id, 'ta_pdt_layouts', true );
		$layout_preset       = isset( $layout['pdt_layout_preset'] ) ? $layout['pdt_layout_preset'] : '';
		$pagination_type     = isset( $view_options['post_pagination_type'] ) ? $view_options['post_pagination_type'] : '';
		$pagination_type     = isset( $view_options['post_pagination_type_mobile'] ) ? $view_options['post_pagination_type_mobile'] : '';
		$query_args          = PDT_QueryInside::get_filtered_content( $view_options, $views_id, $layout_preset );

		$product_offset                   = isset( $view_options['pdt_product_offset'] ) ? $view_options['pdt_product_offset'] : 0;
		$new_query_args                   = $query_args;
		$new_query_args['fields']         = 'ids';
		$product_limit                    = isset( $view_options['pdt_product_limit'] ) && ! empty( $view_options['pdt_product_limit'] ) ? $view_options['pdt_product_limit'] : 10000;
		$new_query_args['posts_per_page'] = $product_limit;
		$query_post_ids                   = get_posts( $new_query_args );

		$relation           = isset( $view_options['pdt_filter_by_taxonomy']['pdt_taxonomies_relation'] ) ? $view_options['pdt_filter_by_taxonomy']['pdt_taxonomies_relation'] : 'AND';
		$query_args         = PDT_Functions::modify_query_params( $query_args, $keyword, $custom_fields_array, $orderby, $order, $selected_term_list, $product_offset, $relation, $query_post_ids, $pdt_lang );
		$query_args['lang'] = '';
		$pdt_query          = new WP_Query( $query_args );
		PDT_HTML::pdt_pagination_bar( $pdt_query, $view_options, $layout, $views_id, $paged );
		die();
	}

	/**
	 * Post Ajax mobile Pagination.
	 */
	public static function post_pagination_bar_mobile() {
		if ( isset( $_POST['nonce'] ) && ! wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['nonce'] ) ), 'sppdt_nonce' ) ) {
			return false;
		}
		$views_id            = isset( $_POST['id'] ) ? absint( $_POST['id'] ) : '';
		$keyword             = isset( $_POST['keyword'] ) ? sanitize_text_field( wp_unslash( $_POST['keyword'] ) ) : '';
		$orderby             = isset( $_POST['orderby'] ) ? sanitize_text_field( wp_unslash( $_POST['orderby'] ) ) : '';
		$order               = isset( $_POST['order'] ) ? sanitize_text_field( wp_unslash( $_POST['order'] ) ) : '';
		$taxonomy            = isset( $_POST['taxonomy'] ) ? sanitize_text_field( wp_unslash( $_POST['taxonomy'] ) ) : '';
		$term_id             = isset( $_POST['term_id'] ) ? sanitize_text_field( wp_unslash( $_POST['term_id'] ) ) : '';
		$pdt_lang            = isset( $_POST['lang'] ) ? sanitize_text_field( wp_unslash( $_POST['lang'] ) ) : '';
		$paged               = isset( $_POST['page'] ) ? sanitize_text_field( wp_unslash( $_POST['page'] ) ) : '';
		$selected_term_list  = isset( $_POST['term_list'] ) ? wp_unslash( $_POST['term_list'] ) : '';
		$custom_fields_array = isset( $_POST['custom_fields_array'] ) ? wp_unslash( $_POST['custom_fields_array'] ) : '';
		$view_options        = get_post_meta( $views_id, 'ta_pdt_view_options', true );
		$layout              = get_post_meta( $views_id, 'ta_pdt_layouts', true );
		$layout_preset       = isset( $layout['pdt_layout_preset'] ) ? $layout['pdt_layout_preset'] : '';
		$pagination_type     = isset( $view_options['post_pagination_type'] ) ? $view_options['post_pagination_type'] : '';
		$pagination_type     = isset( $view_options['post_pagination_type_mobile'] ) ? $view_options['post_pagination_type_mobile'] : '';
		$query_args          = PDT_QueryInside::get_filtered_content( $view_options, $views_id, $layout_preset, 'on_mobile' );
		$tax_settings        = array();
		$product_offset      = isset( $view_options['pdt_product_offset'] ) ? $view_options['pdt_product_offset'] : 0;

		$new_query_args                   = $query_args;
		$new_query_args['fields']         = 'ids';
		$product_limit                    = isset( $view_options['pdt_product_limit'] ) && ! empty( $view_options['pdt_product_limit'] ) ? $view_options['pdt_product_limit'] : 10000;
		$new_query_args['posts_per_page'] = $product_limit;
		$query_post_ids                   = get_posts( $new_query_args );
		$query_post_ids                   = array( '' );

		$relation   = isset( $view_options['pdt_filter_by_taxonomy']['pdt_taxonomies_relation'] ) ? $view_options['pdt_filter_by_taxonomy']['pdt_taxonomies_relation'] : 'AND';
		$query_args = PDT_Functions::modify_query_params( $query_args, $keyword, $custom_fields_array, $orderby, $order, $selected_term_list, $product_offset, $relation, $query_post_ids, $pdt_lang );
		$pdt_query  = new WP_Query( $query_args );
		PDT_HTML::pdt_pagination_bar( $pdt_query, $view_options, $layout, $views_id, $paged, 'on_mobile' );
		die();
	}

	/**
	 * Post Ajax filter.
	 */
	public static function pdt_product_order() {
		if ( isset( $_POST['nonce'] ) && ! wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['nonce'] ) ), 'sppdt_nonce' ) ) {
			return false;
		}
		$views_id               = isset( $_POST['id'] ) ? absint( $_POST['id'] ) : '';
		$keyword                = isset( $_POST['keyword'] ) ? sanitize_text_field( wp_unslash( $_POST['keyword'] ) ) : '';
		$orderby                = isset( $_POST['orderby'] ) ? sanitize_text_field( wp_unslash( $_POST['orderby'] ) ) : '';
		$order                  = isset( $_POST['order'] ) ? sanitize_text_field( wp_unslash( $_POST['order'] ) ) : '';
		$taxonomy               = isset( $_POST['taxonomy'] ) ? sanitize_text_field( wp_unslash( $_POST['taxonomy'] ) ) : '';
		$term_id                = isset( $_POST['term_id'] ) ? sanitize_text_field( wp_unslash( $_POST['term_id'] ) ) : '';
		$pdt_lang               = isset( $_POST['lang'] ) ? sanitize_text_field( wp_unslash( $_POST['lang'] ) ) : '';
		$selected_term_list     = isset( $_POST['term_list'] ) ? wp_unslash( $_POST['term_list'] ) : '';
		$custom_fields_array    = isset( $_POST['custom_fields_array'] ) ? wp_unslash( $_POST['custom_fields_array'] ) : '';
		$layout                 = get_post_meta( $views_id, 'ta_pdt_layouts', true );
		$layout_preset          = isset( $layout['pdt_layout_preset'] ) ? $layout['pdt_layout_preset'] : '';
		$view_options           = get_post_meta( $views_id, 'ta_pdt_view_options', true );
		$pagination_type        = isset( $view_options['post_pagination_type'] ) ? $view_options['post_pagination_type'] : '';
		$pagination_type_mobile = isset( $view_options['post_pagination_type_mobile'] ) ? $view_options['post_pagination_type_mobile'] : '';
		$product_content_sorter = isset( $view_options['post_content_sorter'] ) ? $view_options['post_content_sorter'] : '';
		$query_args             = PDT_QueryInside::get_filtered_content( $view_options, $views_id, $layout_preset );
		$product_offset         = isset( $view_options['pdt_product_offset'] ) ? $view_options['pdt_product_offset'] : 0;

		$new_query_args                   = $query_args;
		$new_query_args['fields']         = 'ids';
		$product_limit                    = isset( $view_options['pdt_product_limit'] ) && ! empty( $view_options['pdt_product_limit'] ) ? $view_options['pdt_product_limit'] : 10000;
		$new_query_args['posts_per_page'] = $product_limit;
		$query_post_ids                   = get_posts( $new_query_args );
		$relation                         = isset( $view_options['pdt_filter_by_taxonomy']['pdt_taxonomies_relation'] ) ? $view_options['pdt_filter_by_taxonomy']['pdt_taxonomies_relation'] : 'AND';
		$query_args                       = PDT_Functions::modify_query_params( $query_args, $keyword, $custom_fields_array, $orderby, $order, $selected_term_list, $product_offset, $relation, $query_post_ids, $pdt_lang );

		$pdt_query = new WP_Query( $query_args );
		PDT_HTML::pdt_get_posts( $view_options, $layout_preset, $product_content_sorter, $pdt_query, $views_id );
		die();
	}



	/**
	 * Function get layout from atts and create class depending on it.
	 *
	 * @since 2.0
	 * @param array $attribute attribute of this shortcode.
	 */
	public function pdt_shortcode_render( $attribute ) {
		if ( empty( $attribute['id'] ) ) {
			return;
		}
		$pdt_gl_id = $attribute['id']; // Productify Pro global ID for Shortcode metaboxes.
		// Preset Layouts.
		$layout        = get_post_meta( $pdt_gl_id, 'ta_pdt_layouts', true );
		$view_options  = get_post_meta( $pdt_gl_id, 'ta_pdt_view_options', true );
		$section_title = get_the_title( $pdt_gl_id );
		ob_start();
		PDT_HTML::pdt_html_show( $view_options, $layout, $pdt_gl_id, $section_title );
		return ob_get_clean();
	}
}
