<?php

/**
 * The file of query insides.
 *
 * @package Productify_pro
 * @subpackage Productify_pro/public
 *
 * @since 2.0.0
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}
/**
 * Post all html method.
 *
 * @since 2.0.0
 */
class PDT_HTML {

	/**
	 * Post title html.
	 *
	 * @param array  $sorter post content option array.
	 * @param string $layout layout preset.
	 * @return void
	 */
	public static function pdt_product_title( $sorter, $layout, $options, $product, $is_table = false ) {
		$_meta_settings      = PDT_Functions::pdt_metabox_value( 'pdt_product_meta', $sorter );
		$product_meta_fields = PDT_Functions::pdt_metabox_value( 'pdt_product_meta_group', $_meta_settings );
		$show_post_meta      = PDT_Functions::pdt_metabox_value( 'show_post_meta', $_meta_settings, true );
		$pdt_page_link_type  = PDT_Functions::pdt_metabox_value( 'pdt_page_link_type', $options );
		$pdt_link_rel        = PDT_Functions::pdt_metabox_value( 'pdt_link_rel', $options );
		$pdt_link_rel_text   = '1' === $pdt_link_rel ? "rel='nofollow'" : '';

		$pdt_link_target = PDT_Functions::pdt_metabox_value( 'pdt_link_target', $options );
		if ( is_array( $product_meta_fields ) && 'accordion_layout' !== $layout && $show_post_meta ) {
			foreach ( $product_meta_fields as $each_meta ) {
				if ( 'taxonomy' === $each_meta['select_post_meta'] ) {
					$taxonomy      = $each_meta['post_meta_taxonomy'];
					$meta_position = $each_meta['pdt_meta_position'];
					if ( 'above_title' === $meta_position ) {
						$terms = get_the_term_list( $product->get_id(), $taxonomy, '', ' ' );
						if ( $terms ) {
							ob_start();
							include PDT_Functions::pdt_locate_template( 'item/meta-over-title.php' );
							$meta_over_title = apply_filters( 'pdt_meta_over_title', ob_get_clean() );
							echo wp_kses_post( $meta_over_title );
						}
					}
				}
			}
		}

		$product_title_setting = isset( $sorter['pdt_product_title'] ) ? $sorter['pdt_product_title'] : '';
		$show_post_title       = PDT_Functions::pdt_metabox_value( 'show_post_title', $product_title_setting );

		$pdt_product_title = get_the_title( $product->get_id() );

		if ( $show_post_title && ! empty( $pdt_product_title ) ) {
			// Post Title Settings.
			$product_title_tag = PDT_Functions::pdt_metabox_value( 'post_title_tag', $product_title_setting, 'h2' );
			$limit_post_title  = PDT_Functions::pdt_metabox_value( 'post_title_limit', $product_title_setting );
			if ( $limit_post_title ) {
				$product_title_length = (int) isset( $product_title_setting['pdt_title_length'] ) ? $product_title_setting['pdt_title_length'] : '';
				$pdt_product_title    = PDT_Functions::limit_post_title( $pdt_product_title, $product_title_length );
			}

			$allowed_html_tags = array(
				'em'     => array(),
				'strong' => array(),
				'sup'    => array(),
				'i'      => array(),
				'small'  => array(),
				'del'    => array(),
				'ins'    => array(),
				'span'   => array(
					'style' => array(),
					'class' => array(),
				),
			);
			$td                = self::table_td( $is_table );
			$allow_tag         = array( 'td' => array() );
			ob_start();
			echo wp_kses( $td['start'], $allow_tag );
			include PDT_Functions::pdt_locate_template( 'item/title.php' );
			echo wp_kses( $td['end'], $allow_tag );
			$title = apply_filters( 'pdt_item_title', ob_get_clean() );
			echo wp_kses_post( $title );
		}
	}

	/**
	 * Show Post Content html.
	 *
	 * @param array $sorter The field ID array.
	 * @param array $options options.
	 * @return void
	 */
	public static function pdt_content_html( $sorter, $options, $product, $is_table = false ) {

		$product_content_setting = PDT_Functions::pdt_metabox_value( 'pdt_product_content', $sorter );
		$show_post_content       = PDT_Functions::pdt_metabox_value( 'show_post_content', $product_content_setting );
		$show_button             = PDT_Functions::pdt_metabox_value( 'show_button', $product_content_setting );
		$pdt_content_type        = PDT_Functions::pdt_metabox_value( 'post_content_type', $product_content_setting );
		$td                      = self::table_td( $is_table );
		$allow_tag               = array( 'td' => array() );
		if ( $show_post_content || $show_button ) {
			ob_start();
			echo wp_kses( $td['start'], $allow_tag );
			include PDT_Functions::pdt_locate_template( 'item/content.php' );
			echo wp_kses( $td['end'], $allow_tag );
			$description = apply_filters( 'pdt_item_description', ob_get_clean() );
			echo wp_kses_post( $description );
		}
	}
	/**
	 * Show Post Content html.
	 *
	 * @param array $sorter The field ID array.
	 * @param array $options options.
	 * @return void
	 */
	public static function pdt_button_html( $sorter, $options, $product, $is_table = false ) {
		$product_content_setting = PDT_Functions::pdt_metabox_value( 'pdt_product_content_button', $sorter );
		$show_button             = PDT_Functions::pdt_metabox_value( 'show_button', $product_content_setting );
		$pdt_content_type        = PDT_Functions::pdt_metabox_value( 'post_content_type', $product_content_setting );
		$td                      = self::table_td( $is_table );
		$allow_tag               = array( 'td' => array() );
		if ( $show_button ) {
			self::pdt_button( $product_content_setting, $pdt_content_type, $options, $product );
		}
	}

	/**
	 * Button function
	 *
	 * @param array $view_options Button options array.
	 * @param array $content_type The content type.
	 * @param array $options The parent of this field.
	 */
	public static function pdt_button( $view_options, $content_type, $options, $product ) {
		$show_button = isset( $view_options['show_button'] ) ? $view_options['show_button'] : '';
		if ( ! $show_button || 'full_content' === $content_type ) {
			return '';
		}
		$button_type        = isset( $view_options['button_type'] ) ? $view_options['button_type'] : '';
		$pdt_read_label     = isset( $view_options['pdt_read_label'] ) ? $view_options['pdt_read_label'] : '';
		$pdt_page_link_type = PDT_Functions::pdt_metabox_value( 'pdt_page_link_type', $options );
		$pdt_link_rel       = PDT_Functions::pdt_metabox_value( 'pdt_link_rel', $options );
		$pdt_link_rel_text  = '';
		if ( $pdt_link_rel ) {
			$pdt_link_rel_text = "rel='nofollow'";
		}
		$readmore_target = PDT_Functions::pdt_metabox_value( 'pdt_link_target', $options );

		ob_start();
		include PDT_Functions::pdt_locate_template( 'item/button.php' );
		$button_button = apply_filters( 'pdt_button_btn', ob_get_clean(), $link = get_permalink( $product ) );
		echo wp_kses_post( $button_button );
	}

	/**
	 * Post thumb HTML.
	 *
	 * @param array $sorter post content option array.
	 * @param int   $scode_id Shortcode ID.
	 * @param int   $slide_id The slide/post ID.
	 * @param array $options The slide/post ID.
	 * @return void
	 */
	public static function pdt_product_thumb_html( $sorter, $scode_id, $product, $options, $layout, $is_table = false ) {
		$_post_thumb_setting = PDT_Functions::pdt_metabox_value( 'pdt_product_thumb', $sorter );
		$pdt_page_link_type  = PDT_Functions::pdt_metabox_value( 'pdt_page_link_type', $options );
		$pdt_link_rel        = PDT_Functions::pdt_metabox_value( 'pdt_link_rel', $options );
		$pdt_product_type    = 'product';

		$product_thumb_meta          = $_post_thumb_setting['post_thumb_meta'];
		$taxonomy_name               = isset( $_post_thumb_setting['post_thumb_meta_taxonomy'] ) ? $_post_thumb_setting['post_thumb_meta_taxonomy'] : '';
		$product_thumb_meta_position = $_post_thumb_setting['post_thumb_meta_position'];
		$meta_date_format            = isset( $each_meta['post_thumb_meta_date_format'] ) ? $each_meta['post_thumb_meta_date_format'] : 'default';
		$is_attachment               = false;
		if ( 'attachment' === $pdt_product_type ) {
			$is_attachment = true;
		}
		$pdt_link_rel_text = '1' === $pdt_link_rel ? "rel='nofollow'" : '';
		$pdt_link_target   = PDT_Functions::pdt_metabox_value( 'pdt_link_target', $options );
		if ( PDT_Functions::pdt_metabox_value( 'post_thumb_show', $_post_thumb_setting ) ) {
			$pdt_image_attr = PDT_Functions::pdt_sized_thumb( $_post_thumb_setting, $product->get_id(), $is_attachment );

			$thumb_url = $pdt_image_attr['src'];

			$retina_img_src  = $pdt_image_attr['2x_src'];
			$retina_img_attr = '';
			if ( ! empty( $retina_img_src ) ) {
				$retina_img_attr = 'srcset="' . esc_attr( $thumb_url ) . ', ' . esc_attr( $retina_img_src ) . ' 2x"';
			}

			$alter_text          = PDT_Functions::pdt_thumb_alter_text( $product->get_id() );
			$_meta_settings      = PDT_Functions::pdt_metabox_value( 'pdt_product_meta', $sorter );
			$product_meta_fields = PDT_Functions::pdt_metabox_value( 'pdt_product_meta_group', $_meta_settings );
			$show_post_meta      = PDT_Functions::pdt_metabox_value( 'show_post_meta', $_meta_settings, true );
			$td                  = self::table_td( $is_table );
			$allow_tag           = array( 'td' => array() );
			if ( ! empty( $thumb_url ) ) {
				ob_start();
				echo wp_kses( $td['start'], $allow_tag );
				include PDT_Functions::pdt_locate_template( 'item/thumbnail.php' );
				echo wp_kses( $td['end'], $allow_tag );
				$item_thumb = apply_filters( 'pdt_item_thumbnail', ob_get_clean() );
				echo $item_thumb; // phpcs:ignore
			}
		}
	}

	/**
	 * Over Thumb meta taxonomy
	 *
	 * @param  mixed  $product_meta_fields meta field.
	 * @param  mixed  $show_post_meta show meta.
	 * @param  object $product post.
	 * @return void
	 */
	public static function over_thumb_meta_taxonomy( $product_meta_fields, $show_post_meta, $product ) {
		if ( is_array( $product_meta_fields ) && $show_post_meta ) {
			foreach ( $product_meta_fields as $each_meta ) {
				if ( 'taxonomy' === $each_meta['select_post_meta'] ) {
					$taxonomy      = $each_meta['post_meta_taxonomy'];
					$meta_position = $each_meta['pdt_meta_position'];
					if ( 'over_thumb' === $meta_position ) {
						$meta_over_thumb_position = isset( $each_meta['pdt_meta_over_thump_position'] ) ? $each_meta['pdt_meta_over_thump_position'] : 'top_left';
						$terms                    = get_the_term_list( $product->get_id(), $taxonomy, '', ' ' );
						if ( $terms ) {
							ob_start();
							include PDT_Functions::pdt_locate_template( 'item/over-thumb-taxonomy.php' );
							$item_over_thumb_taxonomy = apply_filters( 'item_over_thumb_taxonomy', ob_get_clean(), $terms );
							echo wp_kses_post( $item_over_thumb_taxonomy );
						}
					}
				}
			}
		}
	}

	/**
	 * Post Social Html
	 *
	 * @param array  $field_id post content option array.
	 * @param array  $options options.
	 * @param object $pdt_post post.
	 * @param bool   $is_table is table layout.
	 * @return void
	 */
	public static function pdt_social_share_html( $field_id, $pdt_post, $product, $is_table = false ) {
		$product_social     = PDT_Functions::pdt_metabox_value( 'pdt_social_share', $field_id );
		$social_share_media = PDT_Functions::pdt_metabox_value( 'social_sharing_media', $product_social );
		$social_icon_shape  = PDT_Functions::pdt_metabox_value( 'social_icon_shape', $product_social );
		$td                 = self::table_td( $is_table );
		$allow_tag          = array( 'td' => array() );
		?>
		<?php
		if ( $social_share_media ) {
			ob_start();
			echo wp_kses( $td['start'], $allow_tag );
			include PDT_Functions::pdt_locate_template( 'item/social-share.php' );
			echo wp_kses( $td['end'], $allow_tag );
			$social_share = apply_filters( 'pdt_item_social_share', ob_get_clean() );
			echo wp_kses_post( $social_share );
		}
	}

	/**
	 * Post meta HTML
	 *
	 * @param array $sorter post content option array.
	 * @param int   $visitor_count views count.
	 * @return void
	 */
	public static function pdt_product_meta_html( $sorter, $visitor_count, $product, $is_table = false ) {
		$_meta_settings      = PDT_Functions::pdt_metabox_value( 'pdt_product_meta', $sorter );
		$product_meta_fields = PDT_Functions::pdt_metabox_value( 'pdt_product_meta_group', $_meta_settings );
		$show_post_meta      = PDT_Functions::pdt_metabox_value( 'show_post_meta', $_meta_settings, true );
		$_meta_separator     = PDT_Functions::pdt_metabox_value( 'meta_separator', $_meta_settings );

		if ( $product_meta_fields && $show_post_meta ) {

			ob_start();
			include PDT_Functions::pdt_locate_template( 'item/meta.php' );
			$item_meta = apply_filters( 'pdt_item_meta', ob_get_clean() );
			echo wp_kses_post( $item_meta );
		}
	}

	/**
	 * Product Ratting HTML
	 *
	 * @param array $sorter post content option array.
	 * @param int   $visitor_count views count.
	 * @return void
	 */
	public static function pdt_product_rating_html( $sorter, $visitor_count, $product, $is_table = false ) {

		$_pdt_product_rating = PDT_Functions::pdt_metabox_value( 'pdt_product_rating', $sorter );
		$show_product_rating = PDT_Functions::pdt_metabox_value( 'product_rating', $_pdt_product_rating );

		if ( $show_product_rating ) {
			ob_start();
			include PDT_Functions::pdt_locate_template( 'item/rating.php' );
			$rating = apply_filters( 'pdt_rating', ob_get_clean() );
			echo wp_kses_post( $rating );
		}
	}
	/**
	 * Product Price HTML
	 *
	 * @param array $sorter post content option array.
	 * @param int   $visitor_count views count.
	 * @return void
	 */
	public static function pdt_product_price_html( $sorter, $visitor_count, $product, $is_table = false ) {
		$_pdt_product_price = PDT_Functions::pdt_metabox_value( 'pdt_product_price', $sorter );
		$show_product_price = PDT_Functions::pdt_metabox_value( 'product_price', $_pdt_product_price );

		if ( $show_product_price ) {
			ob_start();
			include PDT_Functions::pdt_locate_template( 'item/price.php' );
			$price = apply_filters( 'pdt_price', ob_get_clean() );
			echo wp_kses_post( $price );
		}
	}

	/**
	 * Post content with thumb.
	 *
	 * @param array  $sorter post sorting option.
	 * @param string $layout Layout preset.
	 * @param int    $visitor_count visitor number.
	 * @param int    $scode_id The Shortcode ID.
	 * @param object $product The Post object.
	 * @return void
	 */
	public static function pdt_product_content_with_thumb( $sorter, $layout, $visitor_count, $scode_id, $product, $options, $is_table = false ) {
		if ( $sorter ) {
			foreach ( $sorter as $style_key => $style_value ) {
				switch ( $style_key ) {
					case 'pdt_product_thumb':
						self::pdt_product_thumb_html( $sorter, $scode_id, $product, $options, $layout, $is_table );
						break;
					case 'pdt_product_title':
						self::pdt_product_title( $sorter, $layout, $options, $product, $is_table );
						break;
					case 'pdt_product_content':
						self::pdt_content_html( $sorter, $options, $product, $is_table );
						break;
					case 'pdt_product_content_button':
						self::pdt_button_html( $sorter, $options, $product, $is_table );
						break;
					case 'pdt_product_meta':
						self::pdt_product_meta_html( $sorter, $visitor_count, $product, $is_table );
						break;
					case 'pdt_product_rating':
						self::pdt_product_rating_html( $sorter, $visitor_count, $product, $is_table );
						break;
					case 'pdt_product_price':
						self::pdt_product_price_html( $sorter, $visitor_count, $product, $is_table );
						break;
					case 'pdt_social_share':
						self::pdt_social_share_html( $sorter, $options, $product, $is_table );
						break;
					case 'pdt_custom_fields':
						pdt_custom_field_html( $product, $sorter, true, $is_table );
						break;
				}
			}
		}
	}

	/**
	 * Post content without thumb.
	 *
	 * @param array  $sorter post sorting option.
	 * @param string $layout Layout preset.
	 * @param int    $visitor_count visitor number.
	 * @param object $product visitor number.
	 * @param array  $options Shortcode options.
	 * @return void
	 */
	public static function pdt_product_content_without_thumb( $sorter, $layout, $visitor_count, $scode_id, $product, $options, $is_table = false ) {
		if ( $sorter ) {
			foreach ( $sorter as $style_key => $style_value ) {
				switch ( $style_key ) {
					case 'pdt_product_title':
						self::pdt_product_title( $sorter, $layout, $options, $product, $is_table );
						break;
					case 'pdt_product_content':
						self::pdt_content_html( $sorter, $options, $product, $is_table );
						break;
					case 'pdt_product_content_button':
						self::pdt_button_html( $sorter, $options, $product, $is_table );
						break;
					case 'pdt_product_meta':
						self::pdt_product_meta_html( $sorter, $visitor_count, $product, $is_table );
						break;
					case 'pdt_product_rating':
						self::pdt_product_rating_html( $sorter, $visitor_count, $product, $is_table );
						break;
					case 'pdt_product_price':
						self::pdt_product_price_html( $sorter, $visitor_count, $product, $is_table );
						break;
					case 'pdt_social_share':
						self::pdt_social_share_html( $sorter, $options, $product, $is_table );
						break;
					case 'pdt_custom_fields':
						pdt_custom_field_html( $product, $sorter, true, $is_table );
						break;
				}
			}
		}
	}

	/**
	 * HTML classes for Post.overlay_position
	 *
	 * @return string
	 */
	public static function pdt_alt_post_class( $options, $layout_preset ) {
		if ( 'list_layout' === $layout_preset ) {
			if ( 'left-thumb' === PDT_Functions::pdt_metabox_value( 'post_list_orientation', $options ) ) {
				$pdt_alt_post_class = 'productify__item left-thumb';
			} else {
				$pdt_alt_post_class = 'right-thumb productify__item';
			}
		} elseif ( 'carousel_layout' === $layout_preset || 'grid_layout' === $layout_preset ) {
			if ( 'overlay' === PDT_Functions::pdt_metabox_value( 'post_content_orientation', $options ) ) {
				$pdt_alt_post_class  = 'ta-overlay productify__item ';
				$pdt_alt_post_class .= $options['overlay_position'];
			} else {
				$pdt_alt_post_class = 'productify__item';
			}
		} else {
			$pdt_alt_post_class = 'productify__item';
		}
		return apply_filters( 'post_post_class_name', $pdt_alt_post_class );
	}

	/**
	 * Pagination function
	 *
	 * @param object $loop Query array.
	 * @param array  $view_options options.
	 * @param array  $layout layout.
	 * @param array  $views_id id.
	 * @param array  $paged paged.
	 * @param array  $on_screen screen type.
	 */
	public static function pdt_pagination_bar( $loop, $view_options, $layout, $views_id, $paged = null, $on_screen = null ) {
		$products_found   = $loop->found_posts;
		$product_offset   = isset( $view_options['pdt_product_offset'] ) ? $view_options['pdt_product_offset'] : 0;
		$products_found   = (int) $products_found - (int) $product_offset;
		$product_limit    = isset( $view_options['pdt_product_limit'] ) ? $view_options['pdt_product_limit'] : 100000;
		$product_limit    = ( $product_limit > 0 && $products_found > $product_limit ) ? $product_limit : $products_found;
		$product_per_page = isset( $view_options['post_per_page'] ) ? $view_options['post_per_page'] : 12;
		$product_per_page = ( $product_per_page > $product_limit ) ? $product_limit : $product_per_page;

		$layout_preset = isset( $layout['pdt_layout_preset'] ) ? $layout['pdt_layout_preset'] : '';
		// Post display settings.
		if ( 'filter_layout' === $layout_preset ) {
			$pagination_type = isset( $view_options['filter_pagination_type'] ) ? $view_options['filter_pagination_type'] : '';
		} else {
			$pagination_type = isset( $view_options['post_pagination_type'] ) ? $view_options['post_pagination_type'] : 'ajax_load_more';
			if ( 'on_mobile' === $on_screen ) {
				$pagination_type = isset( $view_options['post_pagination_type_mobile'] ) ? $view_options['post_pagination_type_mobile'] : 'infinite_scroll';
			}
		}
		$product_limit = (int) $product_limit;
		if ( $product_limit < 1 ) {
			$pages = 0;
		} else {
			$pages = PDT_Functions::pdt_max_pages( $product_limit, $product_per_page );
		}
		$big = 999999999; // need an unlikely integer.
		if ( $pages > 1 ) {
			$page_current     = max( 1, get_query_var( 'paged' ) );
			$filter_url_value = isset($_SERVER['QUERY_STRING']) ? wp_unslash($_SERVER['QUERY_STRING']) : ''; //phpcs:ignore
			if ( ! empty( $filter_url_value ) ) {
				$shortcode_id = isset($_GET['pdt']) ? wp_unslash(sanitize_text_field($_GET['pdt'])) : ''; //phpcs:ignore
				if ( $shortcode_id == $views_id ) {
					$pdt_page = isset($_GET['pdt_page']) ? wp_unslash(sanitize_text_field($_GET['pdt_page'])) : ''; //phpcs:ignore
					if ( ! empty( $pdt_page ) ) {
						$page_current = $pdt_page;
					}
				}
			}

			if ( 'ajax_pagination' === $pagination_type ) {
				$page_links = paginate_links(
					array(
						'base'      => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
						'format'    => '?paged=%#%',
						'current'   => $page_current,
						'total'     => $pages,
						'show_all'  => true,
						'prev_next' => false,
						'type'      => 'array',
						'prev_text' => '<i class="fa fa-angle-left"></i>',
						'next_text' => '<i class="fa fa-angle-right"></i>',
					)
				);
				$prev_link  = '<a class="next page-numbers" href="#"><i class="fa fa-angle-right"></i></a>';
				$next_link  = '<a class="prev page-numbers active" href="#"><i class="fa fa-angle-left"></i></a>';
				array_unshift( $page_links, $next_link );
				$page_links[] = $prev_link;
				$html         = '';
				$p_num        = 0;
				foreach ( $page_links as $link ) {
					$class = 'page-numbers ';
					if ( strpos( $link, 'current' ) !== false ) {
						$class .= 'active';
					}
					if ( strpos( $link, 'next' ) !== false ) {
						$data_page = 'data-page="next"';
						$class    .= 'pdt_next ';
					} elseif ( strpos( $link, 'prev' ) !== false ) {
						$data_page = 'data-page="prev"';
						$class    .= 'pdt_prev';
					} else {
						$data_page = 'data-page="' . $p_num . '"';
					}
					$link  = preg_replace( '/<span[^>]*>/', '<a href="#" class="' . $class . '" ' . $data_page . '>', $link );
					$link  = preg_replace( '/<a [^>]*>/', '<a href="#" class="' . $class . '" ' . $data_page . '>', $link );
					$link  = str_replace( '</span>', '</a>', $link );
					$html .= $link;
					++$p_num;
				}
				echo wp_kses_post($html); //phpcs:ignore
			} elseif ( 'no_ajax' === $pagination_type ) {

				$paged_var    = 'paged' . $views_id;
				$page_current = ( ! empty( $_GET[ "$paged_var" ] ) ) ? sanitize_text_field( wp_unslash( $_GET[ "$paged_var" ] ) ) : 1;

				$page_links = paginate_links(
					array(
						'format'    => '?' . $paged_var . '=%#%',
						'current'   => $page_current,
						'total'     => $pages,
						'show_all'  => apply_filters( 'pdt_show_all_normal_pagination', true ),
						'prev_next' => true,
						'end_size'  => 2,
						'mid_size'  => 1,
						'type'      => 'array',
						'prev_text' => '<i class="fa fa-angle-left"></i>',
						'next_text' => '<i class="fa fa-angle-right"></i>',
					)
				);
				echo implode($page_links); //phpcs:ignore
			} else {
				$page_links = paginate_links(
					array(
						'base'      => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
						'format'    => '?paged=%#%',
						'current'   => $page_current,
						'total'     => $pages,
						'show_all'  => true,
						'prev_next' => false,
						'type'      => 'array',
						'prev_text' => '<i class="fa fa-angle-left"></i>',
						'next_text' => '<i class="fa fa-angle-right"></i>',
					)
				);
				$html       = '';
				$p_num      = 1;
				foreach ( $page_links as $link ) {
					$class = 'page-numbers ';
					if ( strpos( $link, 'current' ) !== false ) {
						$class .= 'active';
					}
					if ( strpos( $link, 'next' ) !== false ) {
						$data_page = 'data-page="next"';
						$class    .= 'pdt_next ';
					} elseif ( strpos( $link, 'prev' ) !== false ) {
						$data_page = 'data-page="prev"';
						$class    .= 'pdt_prev active';
					} else {
						$data_page = 'data-page="' . $p_num . '"';
					}
					$link  = preg_replace( '/<span[^>]*>/', '<a href="#" class="' . $class . '" ' . $data_page . '>', $link );
					$link  = preg_replace( '/<a [^>]*>/', '<a href="#" class="' . $class . '" ' . $data_page . '>', $link );
					$link  = str_replace( '</span>', '</a>', $link );
					$html .= $link;
					++$p_num;
				}
				echo wp_kses_post($html); //phpcs:ignore
			}
		}
	}

	/**
	 * Section title
	 *
	 * @param int $pdt_id Shortcode id.
	 * @return void
	 */
	public static function pdt_section_title( $section_title_text, $show_section_title ) {

		if ( $show_section_title ) {
			$section_title_text = apply_filters( 'pdt_section_title_text', $section_title_text );
			ob_start();
			do_action( 'pdt_before_section_title' );
			include PDT_Functions::pdt_locate_template( 'section-title.php' );
			do_action( 'pdt_after_section_title' );
			$section_title = apply_filters( 'pdt_filter_section_title', ob_get_clean() );
			echo wp_kses_post( $section_title );
		}
	}

	/**
	 * Preloader
	 *
	 * @param bool $preloader show preloader.
	 * @return void
	 */
	public static function pdt_preloader( $preloader ) {
		if ( $preloader ) {
			ob_start();
			include PDT_Functions::pdt_locate_template( 'preloader.php' );
			$preloader = apply_filters( 'pdt_preloader', ob_get_clean() );
			echo wp_kses_post( $preloader );
		}
	}

	/**
	 * Get all query posts.
	 *
	 * @param array  $options Views options.
	 * @param array  $layout Layout preset.
	 * @param array  $sorter  Post sorting options.
	 * @param object $pdt_query post query.
	 * @param int    $view_id Shortcode ID.
	 * @return void
	 */
	public static function pdt_get_posts( $options, $layout, $sorter, $pdt_query, $view_id ) {
		$query     = $pdt_query->query;
		$pdt_count = 1;
		$products  = wc_get_products( $query );

		foreach ( $products as $key => $product ) {
			$visitor_count = get_post_meta( $product->get_id(), '_post_views_count', true );
			self::pdt_product_loop( $options, $layout, $sorter, $pdt_count, $view_id, $product );
			++$pdt_count;
		}
	}

	/**
	 * Table td markup.
	 *
	 * @param  mixed $is_table check table layout.
	 * @return array
	 */
	public static function table_td( $is_table = false ) {
		$td_before = '';
		$td_after  = '';
		if ( $is_table ) {
			$td_before = '<td>';
			$td_after  = '</td>';
		}
		return array(
			'start' => $td_before,
			'end'   => $td_after,
		);
	}

	/**
	 * Post responsive columns class.
	 *
	 * @param string $layout Layout preset.
	 * @param string $columns Columns number.
	 * @return string
	 */
	public static function pdt_product_responsive_columns( $layout, $columns ) {

		$pdt_product_columns = '';
		if ( 'carousel_layout' === $layout ) {
			$pdt_product_columns .= ' swiper-slide swiper-lazy';
		} elseif ( 'list_layout' === $layout ) {
			$pdt_product_columns = 'ta-col-xs-1';
		} else {
			$pdt_product_columns .= " ta-col-xs-$columns[mobile] ta-col-sm-$columns[mobile_landscape] ta-col-md-$columns[tablet] ta-col-lg-$columns[desktop] ta-col-xl-$columns[lg_desktop]";
		}
		return $pdt_product_columns;
	}

	/**
	 * Post Loop.
	 *
	 * @param array  $options Views options.
	 * @param string $layout Layout preset.
	 * @param array  $sorter Post sorting options.
	 * @param int    $scode_id Shortcode ID.
	 * @return void
	 */
	public static function pdt_product_loop( $options, $layout, $sorter, $pdt_count, $scode_id, $product ) {
		$number_of_columns = PDT_Functions::pdt_metabox_value( 'pdt_number_of_columns', $options );
		$slide_effect      = PDT_Functions::pdt_metabox_value( 'pdt_slide_effect', $options );
		$visitor_count     = get_post_meta( $product->get_id(), '_post_views_count', true );
		$lazy_load         = PDT_Functions::pdt_metabox_value( 'pdt_lazy_load', $options );
		if ( 'cube' === $slide_effect || 'flip' === $slide_effect ) {
			$lazy_load = 'false';
		}
		if ( ( 'carousel_layout' === $layout || 'grid_layout' === $layout || 'filter_layout' === $layout ) && ( 'default' === PDT_Functions::pdt_metabox_value( 'post_content_orientation', $options ) ) ) {
			?>
			<div class="<?php echo esc_attr( self::pdt_product_responsive_columns( $layout, $number_of_columns, $product->get_id() ) ); ?>">
				<div class="productify__item pdt-item-<?php echo esc_attr( $product->get_id() ); ?>" data-id="<?php echo esc_attr( $product->get_id() ); ?>">
					<?php
					self::pdt_product_content_with_thumb( $sorter, $layout, $visitor_count, $scode_id, $product, $options );
					?>
				</div>
				<?php if ( 'carousel_layout' === $layout && $lazy_load && 'ticker' !== PDT_Functions::pdt_metabox_value( 'pdt_carousel_mode', $options ) ) { ?>
					<!-- <div class="swiper-lazy-preloader swiper-lazy-preloader-black"></div> -->
				<?php } ?>
			</div>
			<?php
		} else {
			$animation_class = '';
			if ( ( 'overlay' === PDT_Functions::pdt_metabox_value( 'post_content_orientation', $options ) || 'overlay-box' === PDT_Functions::pdt_metabox_value( 'post_content_orientation', $options ) ) ) {
				$animation_class = ( 'on_hover' === PDT_Functions::pdt_metabox_value( 'post_overlay_content_visibility', $options ) ) ? PDT_Functions::pdt_metabox_value( 'post_animation', $options ) . ' animated' : '';
			}
			if ( 'list_layout' === $layout || 'zigzag_layout' === $layout ) {
				$animation_class = '';
			}
			?>
			<div class="<?php echo esc_attr( self::pdt_product_responsive_columns( $layout, $number_of_columns, $product->get_id() ) ); ?>">
				<div class="<?php echo esc_attr( self::pdt_alt_post_class( $options, $layout ) ); ?> pdt-item-<?php echo esc_attr( $product->get_id() ); ?>" data-id="<?php echo esc_attr( $product->get_id() ); ?>">
					<?php
					self::pdt_product_thumb_html( $sorter, $scode_id, $product, $options, $layout );
					?>
					<div class="productify__item__details <?php echo esc_html( $animation_class ); ?>">
						<?php
						self::pdt_product_content_without_thumb( $sorter, $layout, $visitor_count, $scode_id, $product, $options );
						?>
					</div>
				</div>
			</div>
			<?php
		}
	}

	/**
	 * PDT shortcode markup wrapper classes.
	 *
	 * @param string $layout_preset The selected layout name.
	 * @param int    $shortcode_id The shortcode ID.
	 */
	public static function pdt_wrapper_classes( $layout_preset, $shortcode_id, $grid_style = null, $item_same_height_class = '' ) {
		$wrapper_class = "ta-pdt-section ta-container pdt-wrapper-{$shortcode_id}";
		switch ( $layout_preset ) {
			case 'carousel_layout':
				$wrapper_class .= " pdt-carousel-wrapper{$item_same_height_class}";
				break;
			case 'grid_layout':
				$wrapper_class .= 'even' === $grid_style ? ' pdt-even' : ' pdt-masonry';
				$wrapper_class .= $item_same_height_class;
				break;
			case 'list_layout':
				$wrapper_class .= $item_same_height_class;
				break;
		}
		echo esc_attr( $wrapper_class );
	}

	/**
	 * Shortcode Wrapper data attributes.
	 *
	 * @param int $shortcode_id The shortcode ID.
	 * @return void
	 */
	public static function wrapper_data( $pagination_type, $pagination_type_mobile, $shortcode_id ) {
		$wrapper_data = '';
		if ( $pagination_type ) {
			$wrapper_data .= " data-pagination={$pagination_type}";
		}
		if ( $pagination_type_mobile ) {
			$wrapper_data .= " data-pagination_mobile={$pagination_type_mobile}";
		}
		if ( $shortcode_id ) {
			$wrapper_data .= " data-sid={$shortcode_id}";
		}
		echo esc_html( $wrapper_data );
	}

	/**
	 * Full html show.
	 *
	 * @param array  $view_options all options.
	 * @param array  $layout show layout.
	 * @param array  $pdt_gl_id Shortcode ID.
	 * @param array  $section_title section title.
	 * @param object $query layout query.
	 */
	public static function pdt_html_show( $view_options, $layout, $pdt_gl_id, $section_title = '', $query = array() ) {
		$options                = $view_options;
		$layout_preset          = isset( $layout['pdt_layout_preset'] ) ? $layout['pdt_layout_preset'] : 'carousel_layout';
		$pdt_settings           = get_option( 'ta_productify_settings' );
		$grid_style             = isset( $view_options['pdt_grid_style'] ) ? $view_options['pdt_grid_style'] : 'even';
		$product_content_sorter = isset( $view_options['post_content_sorter'] ) ? $view_options['post_content_sorter'] : '';
		$show_section_title     = isset( $view_options['section_title'] ) ? $view_options['section_title'] : false;
		$pdt_content_position   = isset( $view_options['post_content_orientation'] ) ? $view_options['post_content_orientation'] : '';
		$margin_between_post    = isset( $view_options['margin_between_post']['all'] ) ? $view_options['margin_between_post']['all'] : '';
		$show_preloader         = isset( $view_options['show_preloader'] ) ? $view_options['show_preloader'] : 0;

		$item_same_height_class = isset( $view_options['item_same_height'] ) && $view_options['item_same_height'] ? ' pdt_same_height ' : '';

		if ( is_object( $query ) && ! empty( $query ) ) {
			$query_args       = array();
			$pdt_query        = $query;
			$total_post_count = $pdt_query->post_count;
		} else {
			$query_args       = PDT_QueryInside::get_filtered_content( $view_options, $pdt_gl_id, $layout_preset );
			$pdt_query        = new WP_Query( $query_args );
			$total_post_count = $pdt_query->post_count;
		}
		// Pagination.
		$show_pagination = isset( $view_options['show_post_pagination'] ) ? $view_options['show_post_pagination'] : true;
		if ( 'filter_layout' === $layout_preset ) {
			$pagination_type        = isset( $view_options['filter_pagination_type'] ) ? $view_options['filter_pagination_type'] : '';
			$pagination_type_mobile = isset( $view_options['filter_pagination_type'] ) ? $view_options['filter_pagination_type'] : '';
		} else {
			$pagination_type        = isset( $view_options['post_pagination_type'] ) ? $view_options['post_pagination_type'] : 'ajax_load_more';
			$pagination_type_mobile = isset( $view_options['post_pagination_type_mobile'] ) ? $view_options['post_pagination_type_mobile'] : 'infinite_scroll';
		}
		$accordion_mode  = isset( $view_options['accordion_mode'] ) ? $view_options['accordion_mode'] : '';
		$advanced_filter = isset( $view_options['pdt_advanced_filter'] ) ? $view_options['pdt_advanced_filter'] : false;
		// Enqueue Settings.
		$swiper_js   = isset( $pdt_settings['pdt_swiper_js'] ) ? $pdt_settings['pdt_swiper_js'] : true;
		$bx_js       = isset( $pdt_settings['pdt_bx_js'] ) ? $pdt_settings['pdt_bx_js'] : true;
		$magnific_js = isset( $pdt_settings['pdt_magnific_js'] ) ? $pdt_settings['pdt_magnific_js'] : true;
		$isotope_js  = isset( $pdt_settings['pdt_isotope_js'] ) ? $pdt_settings['pdt_isotope_js'] : true;
		if ( $magnific_js ) {
			wp_enqueue_script( 'pdt_pdtup' );
		}
		if ( $isotope_js ) {
			wp_enqueue_script( 'pdt_isotope' );
		}
		wp_enqueue_script( 'pdt-script' );
		$pdt_custom_js = isset( $pdt_settings['pdt_custom_js'] ) ? $pdt_settings['pdt_custom_js'] : '';
		if ( ! empty( $pdt_custom_js ) ) {
			wp_add_inline_script( 'pdt-script', $pdt_custom_js );
		}
		$spta_lang = '';
		if ( function_exists( 'pll_current_language' ) ) {
			$spta_lang = pll_current_language();
		}

		if ( 'carousel_layout' === $layout_preset ) {
			include PDT_Functions::pdt_locate_template( 'carousel.php' );
		} elseif ( 'list_layout' === $layout_preset ) {
			include PDT_Functions::pdt_locate_template( 'list.php' );
		} elseif ( 'grid_layout' === $layout_preset ) {
			include PDT_Functions::pdt_locate_template( 'grid.php' );
		} elseif ( 'filter_layout' === $layout_preset ) {
			include PDT_Functions::pdt_locate_template( 'filter.php' );
		}
	}
}
