<?php

/**
 * The file of live filter.
 *
 * @package Productify_pro
 * @subpackage Productify_pro/public/helper
 *
 * @since 2.0.0
 */

/**
 * Live filter helper method.
 *
 * @since 2.0.0
 */
class PDT_Live_Filter {

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    2.0.0
	 */
	public function __construct() {
		add_action( 'wp_ajax_pdt_live_filter_reset', array( $this, 'pdt_live_filter_reset' ) );
		add_action( 'wp_ajax_pdt_admin_live_filter_reset', array( $this, 'pdt_admin_live_filter_reset' ) );
		add_action( 'wp_ajax_nopriv_pdt_live_filter_reset', array( $this, 'pdt_live_filter_reset' ) );
	}
	/**
	 * Live filter markup style.
	 *
	 * @param string $btn_type Filter type.
	 * @param string $taxonomy Current taxonomy to view.
	 * @param string $label filter label.
	 * @param string $all_text all text.
	 * @param string $align alignment.
	 * @param bool   $show_count show hide post count.
	 * @param int    $term term id.
	 * @param string $name term name.
	 * @param int    $p_count term found post.
	 * @param int    $id   post id.
	 * @param string $pre_selected selected.
	 * @param string $pre_checked  checked.
	 * @return array
	 */
	public static function pdt_filter_style( $btn_type, $taxonomy, $label, $all_text, $align = 'center', $show_count = false, $term = null, $name = null, $p_count = null, $id = '', $pre_selected = '', $pre_checked = '' ) {
		if ( $show_count ) {
			$product_count_markup = '<span class="pdt-count">(' . $p_count . ')</span>';
		} else {
			$product_count_markup = '';
		}
		$is_checked       = $pre_checked;
		$is_selected      = $pre_selected;
		$checked          = $pre_checked;
		$selected         = $pre_selected;
		$filter_url_value = isset( $_SERVER['QUERY_STRING'] ) ? wp_unslash( $_SERVER['QUERY_STRING'] ) : '';
		if ( ! empty( $filter_url_value ) ) {
			$shortcode_id = isset( $_GET['p'] ) ? wp_unslash( sanitize_text_field( $_GET['p'] ) ) : '';
			if ( $shortcode_id == $id ) {
				$filter_url_value = isset( $_GET[ "tx_$taxonomy" ] ) ? wp_unslash( sanitize_text_field( $_GET[ "tx_$taxonomy" ] ) ) : '';
				if ( ! empty( $filter_url_value ) ) {
					if ( strpos( $filter_url_value, ',' ) !== false ) {
						$filter_url_value = explode( ',', $filter_url_value );
					}
					if ( is_array( $filter_url_value ) ) {
						if ( in_array( $term, $filter_url_value ) ) {
							$is_checked  = 'checked';
							$is_selected = 'selected';
						} else {
							$is_checked  = $pre_checked;
							$is_selected = $pre_selected;
						}
					} elseif ( $filter_url_value == $term ) {
							$is_checked  = 'checked';
							$is_selected = 'selected';
					} else {
						$is_checked  = $pre_checked;
						$is_selected = $pre_selected;
					}
				}
			}
		}

		$checked  = $pre_checked;
		$selected = $pre_selected;

		if ( 'fl_checkbox' === $btn_type ) {
			$all_label  = ! empty( $all_text ) ? $all_text : '';
			$all_button = ! empty( $all_text ) ? '<div class="fl_checkbox"><label><input checked type="checkbox" name="' . $taxonomy . '" data-taxonomy="' . $taxonomy . '"value="all">' . $all_label . '</label></div>' : '';

			$first_item = '<form class="pdt-filter-by-checkbox pdt-bar" data-taxonomy="' . $taxonomy . '" style="text-align:' . esc_attr( $align ) . ';"> <p>' . esc_html( $label ) . '</p>';
			$push_item  = '<div class="fl_checkbox"><label><input ' . $is_checked . ' name="' . $taxonomy . '" type="checkbox" ' . $checked . ' data-taxonomy="' . $taxonomy . '" value="' . $term . '">' . $name . $product_count_markup . '</span></label></div>';
		} elseif ( 'fl_radio' === $btn_type ) {
			$all_label  = ! empty( $all_text ) ? $all_text : '';
			$all_button = ! empty( $all_text ) ? '<div class="fl_radio"><label><input checked type="radio" name="' . $taxonomy . '" data-taxonomy="' . $taxonomy . '"value="all">' . $all_label . '</label></div>' : '';
			$first_item = '<form class="pdt-filter-by pdt-bar" style="text-align:' . esc_attr( $align ) . ';"> <p>' . esc_html( $label ) . '</p>' . $all_button;
			$push_item  = '<div class="fl_radio"><label><input ' . $is_checked . ' name="' . $taxonomy . '" type="radio" ' . $checked . ' data-taxonomy="' . $taxonomy . '" value="' . $term . '">' . $name . $product_count_markup . '</span></label></div>';
		} elseif ( 'fl_btn' === $btn_type ) {
			$all_label  = ! empty( $all_text ) ? '<div>' . $all_text . '</div>' : '';
			$all_button = ! empty( $all_text ) ? '<div class="fl_radio"><label><input checked type="radio" name="' . $taxonomy . '" data-taxonomy="' . $taxonomy . '" value="all">' . $all_label . '</label></div>' : '';

			$first_item = '<form class="pdt-filter-by pdt-bar fl_button filter-' . $taxonomy . '" style="text-align:' . esc_attr( $align ) . ';"> <p>' . esc_html( $label ) . '</p>' . $all_button;
			$push_item  = '<div class="fl_radio"><label><input ' . $is_checked . ' name="' . $taxonomy . '" type="radio" ' . $checked . ' data-taxonomy="' . $taxonomy . '" value="' . $term . '"><div>' . $name . $product_count_markup . '</div></label></div>';
		} else {
			$all_label  = ! empty( $all_text ) ? $all_text : '';
			$all_button = ! empty( $all_text ) ? '<option value="all"  data-taxonomy="' . $taxonomy . '">' . $all_label . '</option>' : '';

			$first_item = '<form class="pdt-filter-by pdt-bar" style="text-align:' . esc_attr( $align ) . ';"> <label class="pdt-label">' . esc_html( $label ) . '</label> <select>' . $all_button;
			$push_item  = '<option data-taxonomy="' . $taxonomy . '" ' . $selected . ' ' . $is_selected . ' value="' . $term . '">' . $name . $product_count_markup . '</option>';
		}
		$filter_output = array(
			'first_item' => $first_item,
			'push_item'  => $push_item,
		);
		return $filter_output;
	}
	/**
	 * Multi dimensional to flatten array.
	 *
	 * @param array $array input array.
	 * @return array
	 */
	public static function array_flatten( $array ) {
		if ( ! is_array( $array ) ) {
			return false;
		}
		$result = array();
		foreach ( $array as $key => $value ) {
			if ( is_array( $value ) ) {
				$result = array_merge( $result, self::array_flatten( $value ) );
			} else {
				$result[ $key ] = $value;
			}
		}
		return $result;
	}
	/**
	 * Term id list after ajax filter.
	 *
	 * @param object $pdt_query Post query array.
	 * @param object $taxonomies select Taxonomies.
	 * @return Array
	 */
	public static function pdt_all_other_taxonomy_term( $pdt_query, $taxonomies ) {
		$product_ids      = $pdt_query;
		$y                = 0;
		$final_term_list  = array();
		$taxonomies_count = count( $taxonomies );
		while ( $y < $taxonomies_count ) {
			$term_list = array();
			foreach ( $product_ids as $key => $id ) {
				$ct_term = wp_get_post_terms( $id, $taxonomies[ $y ], array( 'fields' => 'ids' ) );
				if ( is_array( $ct_term ) && ! empty( $ct_term ) ) {
					array_push( $term_list, $ct_term );
				}
			}
			$term_list                            = array_unique( self::array_flatten( $term_list ) );
			$final_term_list[ $taxonomies[ $y ] ] = $term_list;
			++$y;
		}
		return $final_term_list;
	}

	/**
	 * All terms form the query
	 *
	 * @param  array  $pdt_query query arg.
	 * @param  string $taxonomy taxonomy.
	 * @return array
	 */
	public static function pdt_all_taxonomy_terms_form_the_query( $pdt_query, $taxonomy ) {
		$product_ids = $pdt_query;
		$term_list   = array();
		foreach ( $product_ids as $key => $id ) {
			$ct_term = wp_get_post_terms( $id, $taxonomy, array( 'fields' => 'ids' ) );
			if ( is_array( $ct_term ) && ! empty( $ct_term ) ) {
				array_push( $term_list, $ct_term );
			}
		}
		return array_unique( self::array_flatten( $term_list ) );
	}
	/**
	 * Live Filter reset after ajax request.
	 */
	public static function pdt_live_filter_reset() {
		if ( isset( $_POST['nonce'] ) && ! wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['nonce'] ) ), 'sppdt_nonce' ) ) {
			return false;
		}
		$pdt_gl_id           = isset( $_POST['id'] ) ? absint( $_POST['id'] ) : '';
		$keyword             = isset( $_POST['keyword'] ) ? sanitize_text_field( wp_unslash( $_POST['keyword'] ) ) : '';
		$orderby             = isset( $_POST['orderby'] ) ? sanitize_text_field( wp_unslash( $_POST['orderby'] ) ) : '';
		$order               = isset( $_POST['order'] ) ? sanitize_text_field( wp_unslash( $_POST['order'] ) ) : '';
		$taxonomy            = isset( $_POST['taxonomy'] ) ? sanitize_text_field( wp_unslash( $_POST['taxonomy'] ) ) : '';
		$term_id             = isset( $_POST['term_id'] ) ? sanitize_text_field( wp_unslash( $_POST['term_id'] ) ) : '';
		$pdt_lang            = isset( $_POST['lang'] ) ? sanitize_text_field( wp_unslash( $_POST['lang'] ) ) : '';
		$last_filter         = isset( $_POST['last_filter'] ) ? sanitize_text_field( wp_unslash( $_POST['last_filter'] ) ) : '';
		$paged               = isset( $_POST['page'] ) ? sanitize_text_field( wp_unslash( $_POST['page'] ) ) : '';
		$custom_fields_array = isset($_POST['custom_fields_array']) ? wp_unslash($_POST['custom_fields_array']) : ''; //phpcs:ignore
		$selected_term_list  = isset($_POST['term_list']) ? wp_unslash($_POST['term_list']) : ''; //phpcs:ignore

		$view_options                 = get_post_meta( $pdt_gl_id, 'ta_pdt_view_options', true );
		$query_args                   = PDT_QueryInside::get_filtered_content( $view_options, $pdt_gl_id );
		$query_args['fields']         = 'ids';
		$product_limit                = isset( $view_options['pdt_product_limit'] ) && ! empty( $view_options['pdt_product_limit'] ) ? $view_options['pdt_product_limit'] : 10000;
		$query_args['posts_per_page'] = $product_limit;
		$query_post_ids               = get_posts( $query_args );
		$relation                     = isset( $view_options['pdt_filter_by_taxonomy']['pdt_taxonomies_relation'] ) ? $view_options['pdt_filter_by_taxonomy']['pdt_taxonomies_relation'] : 'AND';
		$is_term_intersect            = true;
		if ( 'AND' !== $relation ) {
			$is_term_intersect = false;
		}
		$query_args = PDT_Functions::modify_query_params( $query_args, $keyword, $custom_fields_array, $orderby, $order, $selected_term_list, 0, $relation, $query_post_ids, $pdt_lang );
		$pdt_query  = array();
		self::pdt_live_filter( $view_options, $query_args, $pdt_gl_id, $is_term_intersect, $selected_term_list, $last_filter );

		wp_die();
	}

	/**
	 * Taxonomy Filter.
	 *
	 * @param array  $view_options options array.
	 * @param  array  $query_args  query array.
	 * @param  string $id shortcode id.
	 * @param  bool   $is_term_intersect is_ajax.
	 * @param  array  $selected_term_list selected term list.
	 * @param  string $last_filter last filter.
	 * @return void
	 */
	public static function pdt_live_filter( $view_options, $query_args = '', $id = '', $is_term_intersect = true, $selected_term_list = array(), $last_filter = '' ) {
		$filter_by                    = isset( $view_options['pdt_advanced_filter'] ) ? $view_options['pdt_advanced_filter'] : array();
		$product_limit                = isset( $view_options['pdt_product_limit'] ) && ! empty( $view_options['pdt_product_limit'] ) ? $view_options['pdt_product_limit'] : 10000;
		$query_args['posts_per_page'] = $product_limit;
		$query_args['fields']         = 'ids';
		if ( in_array( 'taxonomy', $filter_by, true ) ) {
			$taxonomy_types = isset( $view_options['pdt_filter_by_taxonomy']['pdt_taxonomy_and_terms'] ) && ! empty( $view_options['pdt_filter_by_taxonomy']['pdt_taxonomy_and_terms'] ) ? $view_options['pdt_filter_by_taxonomy']['pdt_taxonomy_and_terms'] : '';
			$relation       = isset( $view_options['pdt_filter_by_taxonomy']['pdt_taxonomies_relation'] ) ? $view_options['pdt_filter_by_taxonomy']['pdt_taxonomies_relation'] : 'AND';
			if ( ! empty( $taxonomy_types ) ) {
				$output         = '';
				$newterm_array  = array();
				$index          = 0;
				$taxonomies     = array();
				$taxonomy_count = count( $taxonomy_types );
				while ( $index < $taxonomy_count ) {
					$add_filter = isset( $taxonomy_types[ $index ]['add_filter_post'] ) ? $taxonomy_types[ $index ]['add_filter_post'] : '';
					if ( $add_filter ) {
						$taxonomy        = isset( $taxonomy_types[ $index ]['pdt_select_taxonomy'] ) ? $taxonomy_types[ $index ]['pdt_select_taxonomy'] : '';
						$all_terms       = get_terms(
							$taxonomy,
							array(
								'get'    => 'all',
								'fields' => 'ids',
							)
						);
						$terms           = isset( $taxonomy_types[ $index ]['pdt_select_terms'] ) ? $taxonomy_types[ $index ]['pdt_select_terms'] : $all_terms;
						$all_post_ids    = get_posts( $query_args );
						$product_limit   = count( $all_post_ids );
						$url_last_filter = isset($_GET['slf']) ? wp_unslash(sanitize_text_field($_GET['slf'])) : ''; //phpcs:ignore

						if ( ! empty( $selected_term_list ) && is_array( $selected_term_list ) ) {
							if ( $last_filter == $taxonomy && 'AND' === $relation ) {
								$new_query = $query_args;
								$tax_query = isset( $new_query['tax_query'] ) ? $new_query['tax_query'] : array();
								if ( ! empty( $tax_query ) ) {
									foreach ( $tax_query as $key => $value ) {
										if ( is_array( $value ) ) {
											if ( $value['taxonomy'] == $taxonomy ) {
												unset( $tax_query[ $key ] );
											}
										}
									}
									$new_query['tax_query'] = $tax_query;
									$all_post_ids           = get_posts( $new_query );
									$product_limit          = count( $all_post_ids );
								}
							}
						} elseif ( $url_last_filter == $taxonomy && 'AND' === $relation ) {
							$new_query = $query_args;
							$tax_query = isset( $new_query['tax_query'] ) ? $new_query['tax_query'] : array();
							if ( ! empty( $tax_query ) ) {
								foreach ( $tax_query as $key => $value ) {
									if ( is_array( $value ) ) {
										if ( $value['taxonomy'] == $taxonomy ) {
											unset( $tax_query[ $key ] );
										}
									}
								}
								$new_query['tax_query'] = $tax_query;
								$all_post_ids           = get_posts( $new_query );
								$product_limit          = count( $all_post_ids );
							}
						}
						$filter_options = isset( $taxonomy_types[ $index ]['ajax_filter_options'] ) ? $taxonomy_types[ $index ]['ajax_filter_options'] : '';
						$all_text       = isset( $filter_options['ajax_rename_all_text'] ) && ! empty( $filter_options['ajax_rename_all_text'] ) ? $filter_options['ajax_rename_all_text'] : '';
						if ( $is_term_intersect ) {
							$new_terms = self::pdt_all_taxonomy_terms_form_the_query( $all_post_ids, $taxonomy );
							$terms     = is_array( $terms ) ? $terms : array( $terms );
							$terms     = array_intersect( $terms, $new_terms );
						}

						$btn_style          = isset( $filter_options['ajax_filter_style'] ) ? $filter_options['ajax_filter_style'] : 'fl_dropdown';
						$hide_taxonomy_name = isset( $taxonomy_types[ $index ]['hide_taxonomy_name'] ) ? $taxonomy_types[ $index ]['hide_taxonomy_name'] : false;
						$show_taxonomy      = ! $hide_taxonomy_name ? $taxonomy : '';
						$label              = isset( $filter_options['ajax_filter_label'] ) && ! empty( $filter_options['ajax_filter_label'] ) ? $filter_options['ajax_filter_label'] : $show_taxonomy;

						$hide_empty = isset( $filter_options['ajax_hide_empty'] ) ? $filter_options['ajax_hide_empty'] : '';
						$show_count = isset( $filter_options['ajax_show_count'] ) ? $filter_options['ajax_show_count'] : '';

						$pdt_live_filter_align = isset( $filter_options['pdt_live_filter_align'] ) ? $filter_options['pdt_live_filter_align'] : 'center';
						if ( $add_filter && ! empty( $terms ) && ! empty( $taxonomy ) ) {
							$filter_item             = self::pdt_filter_style( $btn_style, $taxonomy, $label, $all_text, $pdt_live_filter_align );
							$newterm_array[ $index ] = array( $filter_item['first_item'] );
							foreach ( $terms as $term ) {
								$selected = '';
								$checked  = '';
								if ( ! empty( $selected_term_list ) && is_array( $selected_term_list ) ) {
									foreach ( $selected_term_list as $key => $tax_type ) {
										$cr_taxonomy = $tax_type['taxonomy'];
										$cr_terms    = $tax_type['term_id'];
										if ( strpos( $cr_terms, ',' ) !== false ) {
											$cr_terms = explode( ',', $cr_terms );
										} else {
											$cr_terms = array( $cr_terms );
										}
										if ( $cr_taxonomy == $taxonomy && in_array( $term, $cr_terms ) ) {
											$selected = 'selected';
											$checked  = 'checked';
											break;
										}
									}
								}
								$p_term = get_term( $term, $taxonomy );
								if ( ! is_wp_error( $p_term ) && ! empty( $p_term ) ) {
									$term_post_count = $p_term->count;
									$term_post_count = $term_post_count > $product_limit ? $product_limit : $term_post_count;
									if ( $show_count && 'AND' == $relation ) {
										$count_query              = $query_args;
										$count_query['tax_query'] = array(
											array(
												'taxonomy' => $taxonomy,
												'field'    => 'term_id',
												'terms'    => $term,
											),
										);
										$count_post_posts         = get_posts( $count_query );
										$term_post_count          = count( array_intersect( $count_post_posts, $all_post_ids ) );
									}

									if ( ! $hide_empty ) {
										$push_item = self::pdt_filter_style( $btn_style, $taxonomy, $label, $all_text, $pdt_live_filter_align, $show_count, $term, $p_term->name, $term_post_count, $id, $selected, $checked )['push_item'];
										array_push( $newterm_array[ $index ], $push_item );
									} elseif ( $hide_empty && $term_post_count > 0 ) {
										$push_item = self::pdt_filter_style( $btn_style, $taxonomy, $label, $all_text, $pdt_live_filter_align, $show_count, $term, $p_term->name, $term_post_count, $id, $selected, $checked )['push_item'];
										array_push( $newterm_array[ $index ], $push_item );
									}
								}
							}
							if ( ! $all_text ) {
								$newterm_array[ $index ][1] = preg_replace( '/ type=/i', ' selected checked type=', $newterm_array[ $index ][1] );
							}
							$tax_html = implode( '', $newterm_array[ $index ] );
							$output   = $output . force_balance_tags( $tax_html );
						}
					}
					++$index;
				}
				$allowed_tags = array(
					'form'  => array(
						'class' => array(),
						'style' => array(),
					),
					'p'     => array(),
					'div'   => array(
						'class' => array(),
					),
					'label' => array(),
					'input' => array(
						'checked'       => array(),
						'type'          => array(),
						'name'          => array(),
						'data-taxonomy' => array(),
						'value'         => array(),
					),
				);
				echo wp_kses(
					$output,
					$allowed_tags
				);
			}
		}
	}

	/**
	 * Live Filter reset after ajax request.
	 */
	public static function pdt_admin_live_filter_reset() {
		if ( isset( $_POST['nonce'] ) && ! wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['nonce'] ) ), 'sppdt_nonce' ) ) {
			return false;
		}
		$pdt_gl_id           = isset( $_POST['id'] ) ? absint( $_POST['id'] ) : '';
		$keyword             = isset( $_POST['keyword'] ) ? sanitize_text_field( wp_unslash( $_POST['keyword'] ) ) : '';
		$orderby             = isset( $_POST['orderby'] ) ? sanitize_text_field( wp_unslash( $_POST['orderby'] ) ) : '';
		$order               = isset( $_POST['order'] ) ? sanitize_text_field( wp_unslash( $_POST['order'] ) ) : '';
		$taxonomy            = isset( $_POST['taxonomy'] ) ? sanitize_text_field( wp_unslash( $_POST['taxonomy'] ) ) : '';
		$pdt_lang            = isset( $_POST['lang'] ) ? sanitize_text_field( wp_unslash( $_POST['lang'] ) ) : '';
		$term_id             = isset( $_POST['term_id'] ) ? sanitize_text_field( wp_unslash( $_POST['term_id'] ) ) : '';
		$last_filter         = isset( $_POST['last_filter'] ) ? sanitize_text_field( wp_unslash( $_POST['last_filter'] ) ) : '';
		$paged               = isset( $_POST['page'] ) ? sanitize_text_field( wp_unslash( $_POST['page'] ) ) : '';
		$custom_fields_array = isset($_POST['custom_fields_array']) ? wp_unslash($_POST['custom_fields_array']) : ''; //phpcs:ignore
		$selected_term_list  = isset( $_POST['term_list'] ) ? wp_unslash( $_POST['term_list'] ) : '';
		$settings            = array(); //phpcs:ignore
		parse_str($_POST['data'], $settings); //phpcs:ignore
		$layout                       = $settings['ta_pdt_layouts'];
		$layout_preset                = isset( $layout['pdt_layout_preset'] ) ? $layout['pdt_layout_preset'] : '';
		$view_options                 = $settings['ta_pdt_view_options'];
		$query_args                   = PDT_QueryInside::get_filtered_content( $view_options, $pdt_gl_id );
		$query_args['fields']         = 'ids';
		$new_query_args               = $query_args;
		$product_limit                = isset( $view_options['pdt_product_limit'] ) && ! empty( $view_options['pdt_product_limit'] ) ? $view_options['pdt_product_limit'] : 10000;
		$query_args['posts_per_page'] = $product_limit;
		$query_post_ids               = get_posts( $new_query_args );

		$relation          = isset( $view_options['pdt_filter_by_taxonomy']['pdt_taxonomies_relation'] ) ? $view_options['pdt_filter_by_taxonomy']['pdt_taxonomies_relation'] : 'AND';
		$is_term_intersect = true;
		if ( 'AND' !== $relation ) {
			$is_term_intersect = false;
		}
		$query_args = PDT_Functions::modify_query_params( $query_args, $keyword, $custom_fields_array, $orderby, $order, $selected_term_list, 0, $relation, $query_post_ids, $pdt_lang );
		self::pdt_live_filter( $view_options, $query_args, $pdt_gl_id, $is_term_intersect, $selected_term_list, $last_filter );
		wp_die();
	}


	/**
	 * Final showing terms list
	 *
	 * @param string $taxonomy taxonomy.
	 * @param string $selected_taxonomy Selected taxonomy.
	 * @param array  $all_term all terms id.
	 * @param array  $terms terms.
	 * @param int    $tax_settings_count taxonomy count.
	 * @param array  $selected_taxs Selected taxonomys.
	 * @param array  $is_other_query_active query.
	 * @return object
	 */
	public static function pdt_showing_term( $taxonomy, $selected_taxonomy, $all_term, $terms, $tax_settings_count, $selected_taxs, $is_other_query_active = false ) {
		if ( $selected_taxs ) {
			if ( ( $selected_taxonomy === $taxonomy && $tax_settings_count < 1 ) || ( count( $selected_taxs ) <= 1 && $selected_taxs[0] === $taxonomy ) ) {
				$final_terms = $terms;
			} else {
				$final_terms = array_intersect( $all_term, $terms );
			}
		} elseif ( $is_other_query_active ) {
				$final_terms = array_intersect( $all_term, $terms );
		} else {
			$final_terms = $terms;
		}

		return $final_terms;
	}

	/**
	 * Order filter button.
	 *
	 * @param mixed  $view_options options.
	 * @param string $sid shortcode id.
	 * @return void
	 */
	public static function pdt_order_filter_bar( $view_options, $sid = null ) {
		$filter_by = isset( $view_options['pdt_advanced_filter'] ) ? $view_options['pdt_advanced_filter'] : array();
		if ( in_array( 'sortby', $filter_by ) ) {
			$pdt_filter_by_order     = isset( $view_options['pdt_filter_by_order'] ) ? $view_options['pdt_filter_by_order'] : '';
			$add_filter_post         = isset( $pdt_filter_by_order['add_order_filter_post'] ) ? $pdt_filter_by_order['add_order_filter_post'] : '';
			$ajax_filter_options     = isset( $pdt_filter_by_order['order_filter_options'] ) ? $pdt_filter_by_order['order_filter_options'] : '';
			$pdt_select_filter_order = isset( $pdt_filter_by_order['pdt_select_filter_order'] ) ? $pdt_filter_by_order['pdt_select_filter_order'] : '';
			$pdt_add_filter_orderby  = array( 'DESC', 'ASC' );
			$btn_type                = isset( $ajax_filter_options['order_filter_style'] ) ? $ajax_filter_options['order_filter_style'] : '';
			$label                   = isset( $ajax_filter_options['order_filter_label'] ) ? $ajax_filter_options['order_filter_label'] : '';
			$pdt_live_filter_align   = isset( $ajax_filter_options['pdt_live_filter_align'] ) ? $ajax_filter_options['pdt_live_filter_align'] : 'center';
			if ( $add_filter_post ) {
				$filter_item   = self::pdt_order_filter_style( $btn_type, $label, $pdt_live_filter_align );
				$newterm_array = array( $filter_item['first_item'] );
				foreach ( $pdt_add_filter_orderby as $order ) {
					$push_item = self::pdt_order_filter_style( $btn_type, $label, $pdt_live_filter_align, $order, $pdt_select_filter_order, $sid )['push_item'];
					array_push( $newterm_array, $push_item );
				}
				$tax_html = implode( '', $newterm_array );
				$output   = '';
				$output   = $output . force_balance_tags( $tax_html );
				$allowed_tags = array(
					'form'  => array(
						'class' => array(),
						'style' => array(),
					),
					'p'     => array(),
					'div'   => array(
						'class' => array(),
					),
					'label' => array(),
					'input' => array(
						'checked'       => array(),
						'type'          => array(),
						'name'          => array(),
						'data-taxonomy' => array(),
						'value'         => array(),
					),
				);

				echo wp_kses(
					$output,
					$allowed_tags
				);
			}
		}
	}

	public static function pdt_orderby_filter_style( $btn_type, $label, $align = 'center', $orderby = null, $sid = null ) {
		$filter_url_value        = isset( $_SERVER['QUERY_STRING'] ) ? wp_unslash( $_SERVER['QUERY_STRING'] ) : '';
		$final_orderby_url_value = '';
		if ( ! empty( $filter_url_value ) ) {
			$shortcode_id = isset( $_GET['p'] ) ? wp_unslash( sanitize_text_field( $_GET['p'] ) ) : '';
			if ( $shortcode_id == $sid ) {
				$final_orderby_url_value = isset( $_GET['pdt_orderby'] ) ? sanitize_text_field( wp_unslash( $_GET['pdt_orderby'] ) ) : '';
			}
		}

		if ( $final_orderby_url_value == $orderby ) {
			$is_selected = 'selected';
			$is_checked  = 'checked';
		} else {
			$is_selected = '';
			$is_checked  = '';
		}

		if ( 'fl_radio' === $btn_type ) {
			$first_item = '<div class="pdt-order-by pdt-bar" style="text-align:' . esc_attr( $align ) . ';"><p>' . esc_html( $label ) . '</p><div class="fl_radio"><label><input checked type="radio" name="orderby" value="">None</label></div>';
			$push_item  = '<div class="fl_radio"><label><input name="orderby" type="radio"  ' . $is_checked . ' value="' . $orderby . '">' . $orderby . '</label></div>';
		} elseif ( 'fl_btn' === $btn_type ) {
			$first_item = '<div class="pdt-order-by pdt-bar fl-btn" style="text-align:' . esc_attr( $align ) . ';"><p>' . esc_html( $label ) . '</p> <div class="fl_radio"><label><input checked type="radio" name="orderby" value=""><div>None</div></label></div>';
			$push_item  = '<div class="fl_radio"><label><input type="radio" name="orderby" ' . $is_checked . ' value="' . $orderby . '"><div>' . $orderby . '</div></label></div>';
		} else {
			$first_item = '<div class="pdt-order-by pdt-bar" style="text-align:' . esc_attr( $align ) . ';"><p>' . esc_html( $label ) . '</p><select><option  name="orderby" value="">None</option>';
			$push_item  = '<option name="orderby" ' . $is_selected . ' value="' . $orderby . '">' . $orderby . '</option>';
		}
		$filter_output = array(
			'first_item' => $first_item,
			'push_item'  => $push_item,
		);
		return $filter_output;
	}

	/**
	 * Order filter style
	 *
	 * @param string $btn_type button type.
	 * @param string $label order filter label.
	 * @param string $align alignment text.
	 * @param string $order order text.
	 * @param string $select_order selected order.
	 * @param string $sid shortcode id.
	 */
	public static function pdt_order_filter_style( $btn_type, $label, $align = 'center', $order = null, $select_order = null, $sid = null ) {
		$final_order_url_value = '';
		$filter_url_value      = isset( $_SERVER['QUERY_STRING'] ) ? wp_unslash( $_SERVER['QUERY_STRING'] ) : '';
		if ( ! empty( $filter_url_value ) ) {
			$shortcode_id = isset( $_GET['p'] ) ? wp_unslash( sanitize_text_field( $_GET['p'] ) ) : '';
			if ( $shortcode_id == $sid ) {
				$final_order_url_value = isset( $_GET['pdt_order'] ) ? sanitize_text_field( wp_unslash( $_GET['pdt_order'] ) ) : '';
			}
		}

		if ( $final_order_url_value == $order ) {
			$checked  = 'checked';
			$selected = 'selected';
		} else {
			$selected = '';
			$checked  = '';
		}
		if ( 'fl_radio' === $btn_type ) {
			$first_item = '<div class="pdt-order pdt-bar" style="text-align:' . esc_attr( $align ) . ';"><p>' . esc_html( $label ) . '</p>';
			$push_item  = '<div class="fl_radio"><label><input name="order" ' . $checked . ' type="radio" value="' . $order . '">' . $order . '</label></div>';
		} elseif ( 'fl_btn' === $btn_type ) {
			$first_item = '<div class="pdt-order pdt-bar fl-btn" style="text-align:' . esc_attr( $align ) . ';"><p>' . esc_html( $label ) . '</p>';
			$push_item  = '<div class="fl_radio"><label><input type="radio" ' . $checked . ' name="order" value="' . $order . '"><div>' . $order . '</div></label></div>';
		} else {
			$first_item = '<div class="pdt-order pdt-bar" style="text-align:' . esc_attr( $align ) . ';"><p>' . esc_html( $label ) . '</p><select>';
			$push_item  = '<option name="order" ' . $selected . ' value="' . $order . '">' . $order . '</option>';
		}
		$filter_output = array(
			'first_item' => $first_item,
			'push_item'  => $push_item,
		);
		return $filter_output;
	}

	/**
	 * Live search bar
	 *
	 * @param int    $view_options options.
	 * @param string $sid shortcode id.
	 * @return void
	 */
	public static function pdt_live_search_bar( $view_options, $sid = null ) {
		$filter_by        = isset( $view_options['pdt_advanced_filter'] ) ? $view_options['pdt_advanced_filter'] : array();
		$final_keyword    = '';
		$filter_url_value = isset( $_SERVER['QUERY_STRING'] ) ? wp_unslash( $_SERVER['QUERY_STRING'] ) : '';
		if ( ! empty( $filter_url_value ) ) {
			$shortcode_id = isset( $_GET['p'] ) ? wp_unslash( sanitize_text_field( $_GET['p'] ) ) : '';
			if ( $shortcode_id == $sid ) {
				$final_keyword = isset( $_GET['pdt_keyword'] ) ? sanitize_text_field( wp_unslash( $_GET['pdt_keyword'] ) ) : '';
			}
		}
		if ( in_array( 'keyword', $filter_by, true ) ) {
			$pdt_filter_by_keyword = isset( $view_options['pdt_filter_by_keyword'] ) ? $view_options['pdt_filter_by_keyword'] : '';
			$add_filter_post       = isset( $pdt_filter_by_keyword['add_search_filter_post'] ) ? $pdt_filter_by_keyword['add_search_filter_post'] : '';
			if ( $add_filter_post ) {
				$ajax_filter_options   = isset( $pdt_filter_by_keyword['ajax_filter_options'] ) ? $pdt_filter_by_keyword['ajax_filter_options'] : '';
				$label                 = isset( $ajax_filter_options['ajax_filter_label'] ) && ! empty( $ajax_filter_options['ajax_filter_label'] ) ? $ajax_filter_options['ajax_filter_label'] : '';
				$pdt_live_filter_align = isset( $ajax_filter_options['pdt_live_filter_align'] ) ? $ajax_filter_options['pdt_live_filter_align'] : 'center';
				echo '<div class="pdt-ajax-search pdt-bar" style="text-align:' . esc_attr( $pdt_live_filter_align ) . ';"><label class="pdt-label">' . wp_kses_post( $label ) . ' <input type="text" value="' . esc_attr( $final_keyword ) . '" class="pdt-search-field" placeholder="Search..."></label></div>';
			}
		}
	}
}
